<template>
  <div>
    <el-form label-width="100px" size="mini">
      <el-form-item label="柱类型">
        <el-select v-model="attribute.barType">
          <el-option label="普通柱状图" value="bar"/>
          <el-option label="象形柱状图" value="pictorialBar"/>
        </el-select>
      </el-form-item>
      <el-form-item label="柱体样式" v-show="attribute.barType === 'pictorialBar'">
        <el-select v-model="attribute.barPath">
          <el-option v-for="(item,index) in barPaths" :key="index" :label="item.label" :value="item.value"/>
        </el-select>
      </el-form-item>
      <el-form-item label="标题">
        <el-input v-model="attribute.chartTitle"/>
      </el-form-item>
      <el-form-item label="标题位置(左)">
        <el-input v-model="attribute.titleLeft"/>
      </el-form-item>
      <el-form-item label="标题位置(上)">
        <el-input v-model="attribute.titleTop"/>
      </el-form-item>
      <el-form-item label="标题颜色">
        <color-picker v-model="attribute.titleTextColor" show-alpha/>
      </el-form-item>
      <el-form-item label="x轴">
        <el-switch v-model="attribute.xAxisShow" active-text="开" inactive-text="关"/>
      </el-form-item>
      <div v-show="attribute.xAxisShow">
        <el-form-item label="x轴线显示">
          <el-switch v-model="attribute.xLineShow" active-text="开" inactive-text="关"/>
        </el-form-item>
        <el-form-item label="x轴线颜色">
          <color-picker v-model="attribute.xLineColor" show-alpha/>
        </el-form-item>
        <el-form-item label="x轴刻度线">
          <el-switch v-model="attribute.xTickShow" active-text="开" inactive-text="关"/>
        </el-form-item>
        <el-form-item label="x轴字体颜色">
          <color-picker v-model="attribute.xLabelColor" show-alpha/>
        </el-form-item>
        <el-form-item label="x轴字体倾斜">
          <el-slider v-model="attribute.xFontRotate" :min="-180" :max="180"/>
        </el-form-item>
      </div>
      <el-form-item label="y轴">
        <el-switch v-model="attribute.yAxisShow" active-text="开" inactive-text="关"/>
      </el-form-item>
      <div v-show="attribute.yAxisShow">
        <el-form-item label="y轴线显示">
          <el-switch v-model="attribute.yLineShow" active-text="开" inactive-text="关"/>
        </el-form-item>
        <el-form-item label="y轴颜色">
          <color-picker v-model="attribute.yLineColor" show-alpha/>
        </el-form-item>
        <el-form-item label="y轴网格线">
          <el-switch v-model="attribute.yGridLineShow" active-text="开" inactive-text="关"/>
        </el-form-item>
        <el-form-item label="y轴刻度线">
          <el-switch v-model="attribute.yTickShow" active-text="开" inactive-text="关"/>
        </el-form-item>
        <el-form-item label="y轴字体颜色">
          <color-picker v-model="attribute.yLabelColor" show-alpha/>
        </el-form-item>
      </div>
      <el-form-item label="颜色渐变">
        <el-switch v-model="attribute.gradualColor" active-text="开" inactive-text="关"/>
      </el-form-item>
      <div v-if="attribute.gradualColor">
        <el-form-item label="柱顶颜色">
          <color-picker v-model="attribute.barColor1" show-alpha/>
        </el-form-item>
        <el-form-item label="柱中颜色">
          <color-picker v-model="attribute.barColor2" show-alpha/>
        </el-form-item>
        <el-form-item label="柱底颜色">
          <color-picker v-model="attribute.barColor3" show-alpha/>
        </el-form-item>
      </div>
      <div v-else>
        <el-form-item label="柱体颜色">
          <ColorPicker v-model="attribute.barColor" show-alpha/>
        </el-form-item>
      </div>
      <el-form-item label="柱体背景" v-show="attribute.barType === 'bar'">
        <el-switch v-model="attribute.barBgShow" active-text="开" inactive-text="关"/>
      </el-form-item>
      <el-form-item label="圆角" v-show="attribute.barType === 'bar'">
        <el-input-number v-model="attribute.barBorderRadius" :min="0" :max="50"/>
      </el-form-item>
      <el-form-item label="柱体宽度">
        <el-input-number v-model="attribute.barWidth" :min="1" :max="100"/>
      </el-form-item>
      <el-form-item label="数值显示">
        <el-switch v-model="attribute.barLabelShow" active-text="开" inactive-text="关"/>
      </el-form-item>
      <div v-show="attribute.barLabelShow">
        <el-form-item label="数值字体">
          <el-input-number v-model="attribute.barLabelSize" :min="2" :max="100"/>
        </el-form-item>
        <el-form-item label="数值颜色">
          <color-picker v-model="attribute.barLabelColor" show-alpha/>
        </el-form-item>
      </div>
    </el-form>
  </div>
</template>

<script>
export default {
  name: "cpt-chart-column-option",
  props: {
    attribute: Object
  },
  data(){
    return {
      barPaths:[
        {label: '锥形', value: 'path://M0,10 L10,10 C5.5,10 5.5,5 5,0 C4.5,5 4.5,10 0,10 z'},
        {label: '铅笔手绘', value: 'path://d="M-135.22,142.85l-2.04-2.23l0.74-0.67l2.03,2.22L-135.22,142.85zM-132.31,142.21c-0.29-0.36-0.63-0.63-0.96-0.9l-0.3-0.25c-0.98-0.82-1.77-1.89-2.53-2.92c-0.07-0.09-0.14-0.18-0.16-0.26l-0.93,0.36c0.08,0.2,0.2,0.36,0.29,0.49c0.8,1.07,1.63,2.18,2.69,3.08l0.32,0.26c0.3,0.24,0.59,0.47,0.81,0.74L-132.31,142.21zM-127.58,142.35c-1.06-0.62-2-1.4-2.79-2.33c-0.33-0.38-0.63-0.79-0.94-1.19c-0.55-0.72-1.11-1.47-1.82-2.1c-0.36-0.32-0.76-0.61-1.14-0.88c-0.79-0.57-1.53-1.1-1.92-1.88l-0.89,0.45c0.5,0.99,1.38,1.63,2.23,2.24c0.38,0.27,0.74,0.53,1.06,0.82c0.63,0.56,1.14,1.24,1.68,1.95c0.32,0.42,0.63,0.84,0.98,1.24c0.87,1.01,1.89,1.86,3.04,2.54L-127.58,142.35zM-125.88,142.26c-0.79-1.32-2.01-2.36-3.44-2.92l-0.23-0.09c-0.24-0.09-0.47-0.17-0.65-0.29c-0.26-0.16-0.47-0.42-0.7-0.68l-3.19-3.75c-0.66-0.77-1.4-1.65-2.39-2.2l-0.49,0.87c0.83,0.46,1.48,1.23,2.11,1.97l3.19,3.75c0.25,0.3,0.54,0.63,0.92,0.88c0.28,0.18,0.56,0.29,0.84,0.39l0.21,0.08c1.23,0.49,2.27,1.38,2.94,2.51L-125.88,142.26zM-122.1,142.09l-3.66-2.92c-0.79-0.63-1.61-1.28-2.33-2c-0.52-0.51-1-1.08-1.48-1.63c-0.58-0.68-1.19-1.38-1.87-2.01c-0.53-0.49-1.1-0.94-1.66-1.38c-1.33-1.04-2.59-2.03-3.19-3.46l-0.92,0.39c0.7,1.67,2.12,2.78,3.49,3.85c0.54,0.42,1.1,0.86,1.59,1.32c0.64,0.59,1.22,1.27,1.79,1.93c0.49,0.57,0.99,1.15,1.53,1.69c0.76,0.75,1.6,1.42,2.42,2.08l3.65,2.92L-122.1,142.09zM-118.79,142.29c-1.53-1.84-3.27-3.49-5.18-4.92c-0.22-0.17-0.45-0.33-0.67-0.49c-0.41-0.3-0.82-0.59-1.21-0.91c-0.83-0.67-1.61-1.45-2.37-2.21l-3.38-3.37c-1.73-1.72-3.52-3.5-5-5.47l-0.8,0.6c1.53,2.02,3.34,3.83,5.1,5.58l3.39,3.37c0.77,0.77,1.57,1.56,2.45,2.27c0.41,0.33,0.83,0.63,1.25,0.94c0.22,0.16,0.44,0.32,0.66,0.48c1.85,1.38,3.53,2.98,5.01,4.76L-118.79,142.29zM-117.85,141.75c-0.7-0.1-1.21-0.76-1.74-1.46l-0.27-0.35c-0.95-1.19-2.15-2.11-3.31-3.01c-0.85-0.66-1.73-1.34-2.48-2.1c-0.32-0.33-0.63-0.68-0.93-1.03c-0.38-0.43-0.77-0.88-1.2-1.29c-0.48-0.46-1.01-0.88-1.51-1.28l-0.5-0.39c-2.48-2.01-4.66-4.44-6.76-6.8l-0.75,0.67c2.13,2.39,4.33,4.86,6.88,6.92l0.5,0.4c0.51,0.4,0.99,0.78,1.44,1.21c0.4,0.38,0.76,0.79,1.14,1.23c0.32,0.36,0.63,0.73,0.97,1.07c0.8,0.81,1.71,1.51,2.58,2.19c1.17,0.9,2.27,1.75,3.14,2.84l0.26,0.34c0.61,0.79,1.29,1.68,2.39,1.84L-117.85,141.75zM-114.48,142.01c-0.46-0.56-0.89-1.17-1.31-1.76c-0.21-0.3-0.43-0.61-0.65-0.91c-1.49-2.03-3.24-3.89-4.94-5.68l-4.8-5.07c-3.1-3.28-6.31-6.67-9.99-9.47l-0.61,0.79c3.61,2.75,6.79,6.11,9.87,9.36l4.8,5.07c1.67,1.77,3.4,3.6,4.86,5.58c0.22,0.29,0.43,0.59,0.64,0.89c0.43,0.61,0.87,1.23,1.36,1.82L-114.48,142.01zM-111.55,142.12c-2.9-2.21-5.16-5.18-7.34-8.05c-1.43-1.88-2.91-3.83-4.57-5.58c-0.54-0.57-1.1-1.12-1.66-1.67c-0.89-0.88-1.82-1.79-2.64-2.75c-1.03-1.22-1.95-2.57-2.83-3.89c-0.58-0.87-1.19-1.76-1.82-2.62c-0.91-1.21-2.17-2.64-3.9-2.92l-0.16,0.99c1.37,0.22,2.41,1.4,3.25,2.53c0.62,0.84,1.22,1.72,1.8,2.58c0.9,1.34,1.83,2.72,2.9,3.98c0.85,1,1.79,1.92,2.7,2.82c0.55,0.54,1.1,1.09,1.64,1.65c1.63,1.71,3.09,3.64,4.5,5.5c0.82,1.08,1.66,2.18,2.53,3.25c-1.29-1.06-2.53-2.17-3.74-3.32c-1.43-1.36-2.83-2.8-4.18-4.2l-2.89-2.99c-0.76-0.78-1.54-1.59-2.22-2.45c-0.26-0.33-0.51-0.67-0.76-1.01c-0.31-0.42-0.62-0.84-0.95-1.25c-0.44-0.54-0.93-1.05-1.4-1.55c-1.13-1.2-2.19-2.32-2.71-3.76l-0.94,0.34c0.58,1.63,1.77,2.89,2.92,4.11c0.46,0.49,0.93,0.99,1.35,1.5c0.32,0.39,0.62,0.8,0.91,1.2c0.26,0.35,0.51,0.7,0.78,1.04c0.71,0.9,1.51,1.72,2.28,2.52l2.89,2.99c1.36,1.4,2.76,2.85,4.21,4.23c2.92,2.78,6.1,5.34,9.45,7.6L-111.55,142.12zM-109.4,135.96c-1.89-3.29-4.33-6.92-8.1-8.9c-0.61-0.32-1.26-0.6-1.89-0.87c-1.53-0.66-2.98-1.28-3.93-2.47c-0.36-0.45-0.64-0.97-0.92-1.53c-0.16-0.3-0.31-0.59-0.48-0.88c-0.69-1.17-1.6-2.18-2.48-3.15c-2.9-3.2-5.89-6.5-9.21-9.41l-0.66,0.75c3.27,2.87,6.25,6.15,9.13,9.33c0.85,0.93,1.72,1.9,2.36,2.98c0.16,0.27,0.31,0.55,0.46,0.84c0.3,0.57,0.61,1.15,1.03,1.68c1.11,1.39,2.74,2.09,4.32,2.77c0.61,0.26,1.24,0.53,1.82,0.84c3.54,1.86,5.88,5.35,7.7,8.52L-109.4,135.96zM-109.82,139.95c-1.73-2.07-3.53-4.21-5.54-6.12c-1.01-0.95-2.08-1.86-3.12-2.73c-0.86-0.72-1.72-1.45-2.55-2.21c-1.41-1.29-2.77-2.7-4.08-4.07c-1.95-2.03-3.96-4.13-6.23-5.9l-0.61,0.79c2.21,1.72,4.2,3.79,6.13,5.8c1.32,1.38,2.69,2.8,4.13,4.11c0.84,0.77,1.71,1.5,2.58,2.23c1.03,0.87,2.09,1.76,3.08,2.7c1.97,1.87,3.74,3.98,5.46,6.03L-109.82,139.95zM-109.46,130.06l-2.51-2.32c-0.82-0.76-1.68-1.55-2.57-2.28c-0.46-0.37-0.93-0.73-1.4-1.08c-0.5-0.38-1-0.76-1.48-1.15c-1.02-0.83-1.99-1.77-2.95-2.7c-5.42-5.25-11.03-10.68-15.96-16.54l-0.76,0.64c4.97,5.9,10.59,11.35,16.05,16.64c0.95,0.92,1.94,1.88,2.99,2.74c0.49,0.41,1,0.79,1.51,1.18c0.46,0.35,0.92,0.7,1.37,1.06c0.87,0.71,1.71,1.48,2.54,2.25l2.49,2.31L-109.46,130.06zM-109.68,125.89c-2.95-3.8-6.44-7.12-10.37-9.87l-0.31-0.21c-0.52-0.36-1.02-0.71-1.48-1.1c-0.82-0.7-1.49-1.53-2.21-2.41c-0.19-0.23-0.38-0.47-0.57-0.7c-3.38-4.06-7.6-7.3-11.69-10.44l-0.61,0.79c4.04,3.1,8.22,6.31,11.53,10.29c0.19,0.23,0.38,0.46,0.56,0.69c0.71,0.88,1.44,1.78,2.33,2.54c0.5,0.43,1.04,0.8,1.56,1.16l0.3,0.21c3.85,2.69,7.27,5.95,10.16,9.66L-109.68,125.89zM-109.51,122.59c-2.94-2.24-5.55-4.98-8.07-7.63c-1.89-1.99-3.85-4.06-5.95-5.91c-0.31-0.27-0.61-0.53-0.92-0.8c-0.55-0.48-1.11-0.95-1.64-1.45c-1.12-1.05-2.16-2.24-3.19-3.4l-6.98-7.91l-0.75,0.66l6.99,7.93c1.02,1.16,2.08,2.36,3.24,3.45c0.54,0.51,1.11,0.99,1.67,1.48c0.31,0.26,0.61,0.52,0.91,0.79c2.07,1.82,4.01,3.87,5.89,5.85c2.55,2.68,5.18,5.46,8.19,7.74L-109.51,122.59zM-120.82,115.56c-1.07-1.61-2.17-3.28-3.46-4.78c-0.64-0.75-1.33-1.46-2-2.16l-9.54-9.9l-0.72,0.69l9.54,9.9c0.66,0.68,1.33,1.39,1.95,2.11c1.25,1.46,2.33,3.1,3.39,4.68L-120.82,115.56zM-109.43,119.67c-1.56-2.11-3.37-4.05-5.11-5.93c-1.26-1.35-2.56-2.75-3.96-4.03c-0.62-0.57-1.26-1.11-1.91-1.66c-0.74-0.63-1.5-1.28-2.21-1.95c-0.69-0.65-1.36-1.35-2.01-2.02l-12-12.46l-0.72,0.69l12,12.46c0.66,0.68,1.34,1.39,2.05,2.06c0.73,0.69,1.5,1.34,2.25,1.98c0.63,0.54,1.27,1.08,1.88,1.64c1.37,1.25,2.66,2.63,3.9,3.97c1.73,1.86,3.52,3.78,5.04,5.84L-109.43,119.67zM-109.44,114.82l-7-6.17c-0.98-0.87-1.96-1.73-2.93-2.62c-2.52-2.32-4.93-4.79-7.17-7.36c-0.87-1-1.72-2.02-2.58-3.04c-2.32-2.78-4.73-5.66-7.52-8.08l-0.65,0.76c2.74,2.37,5.11,5.21,7.41,7.97c0.86,1.03,1.71,2.05,2.59,3.06c2.26,2.6,4.7,5.1,7.25,7.44c0.97,0.89,1.96,1.76,2.94,2.63l7,6.17L-109.44,114.82zM-109.48,112.48c-1.29-1.13-2.54-2.34-3.75-3.51c-3.41-3.32-6.94-6.75-10.17-10.35l-0.58-0.65c-1-1.13-2.04-2.3-3.2-3.33c-0.41-0.36-0.83-0.71-1.25-1.06c-0.61-0.5-1.24-1.02-1.8-1.58c-0.92-0.92-1.73-2-2.5-3.05c-1.18-1.59-2.39-3.23-4.07-4.39l-0.57,0.82c1.54,1.06,2.66,2.57,3.83,4.16c0.8,1.08,1.63,2.2,2.6,3.17c0.59,0.59,1.24,1.12,1.87,1.64c0.41,0.34,0.82,0.67,1.22,1.03c1.11,0.99,2.13,2.14,3.12,3.25l0.58,0.65c3.25,3.63,6.79,7.07,10.22,10.4c1.22,1.18,2.48,2.41,3.79,3.55L-109.48,112.48zM-109.59,109.06c-0.51-1.1-1.49-1.77-2.43-2.42c-0.62-0.42-1.2-0.82-1.65-1.33c-0.23-0.25-0.42-0.54-0.63-0.84c-0.24-0.34-0.48-0.7-0.79-1.02c-0.38-0.4-0.82-0.72-1.27-1.04l-0.15-0.11c-0.68-0.48-1.32-0.93-1.82-1.52c-0.23-0.27-0.44-0.57-0.64-0.87c-0.16-0.24-0.32-0.47-0.49-0.7c-0.71-0.92-1.61-1.66-2.48-2.36c-0.97-0.79-1.9-1.53-2.54-2.51l-0.17-0.26c-0.19-0.3-0.38-0.61-0.67-0.89c-0.31-0.3-0.67-0.49-0.99-0.67c-1.21-0.66-2.46-1.33-3.26-2.39c-0.24-0.32-0.45-0.68-0.66-1.06c-0.17-0.3-0.34-0.6-0.52-0.88c-0.58-0.87-1.33-1.59-2.05-2.28l-3.7-3.52l-0.69,0.72l3.7,3.52c0.68,0.65,1.39,1.33,1.91,2.11c0.18,0.26,0.33,0.54,0.49,0.82c0.22,0.39,0.45,0.8,0.73,1.17c0.93,1.24,2.34,2,3.58,2.67c0.28,0.15,0.56,0.31,0.78,0.51c0.19,0.18,0.35,0.43,0.51,0.69l0.18,0.28c0.73,1.1,1.76,1.93,2.75,2.74c0.87,0.7,1.69,1.36,2.32,2.19c0.16,0.21,0.31,0.43,0.46,0.65c0.22,0.32,0.44,0.65,0.71,0.96c0.58,0.68,1.3,1.19,2,1.68l0.15,0.11c0.43,0.3,0.8,0.58,1.12,0.91c0.25,0.27,0.47,0.58,0.69,0.91c0.22,0.31,0.44,0.64,0.71,0.94c0.53,0.6,1.19,1.05,1.83,1.49c0.87,0.6,1.69,1.16,2.09,2.02L-109.59,109.06zM-109.78,105.4l-12.28-11.48c-0.66-0.62-1.34-1.25-1.93-1.95c-0.35-0.41-0.66-0.84-0.98-1.27c-0.33-0.45-0.66-0.89-1.02-1.32c-0.68-0.8-1.44-1.5-2.18-2.18l-5.37-4.94c-0.97-0.89-1.97-1.81-3.15-2.5l-0.5,0.86c1.09,0.63,2.05,1.51,2.98,2.37l5.37,4.94c0.72,0.66,1.46,1.34,2.09,2.09c0.34,0.41,0.66,0.83,0.98,1.26c0.33,0.45,0.66,0.9,1.02,1.32c0.63,0.74,1.33,1.4,2.01,2.03l12.28,11.48L-109.78,105.4zM-109.73,99.67c-1.91-1.09-3.43-2.67-5.04-4.33c-1.09-1.13-2.22-2.3-3.48-3.3c-0.28-0.22-0.57-0.44-0.86-0.65c-0.61-0.45-1.18-0.88-1.69-1.38c-0.61-0.6-1.12-1.29-1.66-2.03c-0.29-0.39-0.57-0.78-0.88-1.16c-0.69-0.86-1.48-1.65-2.25-2.43c-3.52-3.55-7.17-7.21-11.14-10.42l-0.63,0.78c3.93,3.17,7.55,6.81,11.07,10.36c0.74,0.75,1.5,1.52,2.17,2.34c0.29,0.37,0.57,0.75,0.85,1.13c0.54,0.73,1.09,1.49,1.76,2.15c0.56,0.55,1.19,1.01,1.79,1.46c0.28,0.21,0.56,0.42,0.84,0.63c1.2,0.95,2.31,2.1,3.38,3.21c1.58,1.64,3.22,3.34,5.26,4.51L-109.73,99.67zM-109.6,95.62c-1.79-1.93-3.88-3.58-5.9-5.17c-2.21-1.75-4.5-3.55-6.35-5.7c-0.46-0.54-0.91-1.11-1.35-1.67c-1.27-1.62-2.59-3.3-4.42-4.38c-0.34-0.2-0.7-0.37-1.05-0.55c-0.49-0.24-0.96-0.47-1.38-0.76c-1.21-0.83-2-2.13-2.84-3.5c-0.99-1.61-2.02-3.28-3.78-4.14l-0.44,0.9c1.5,0.73,2.41,2.2,3.37,3.76c0.86,1.4,1.75,2.84,3.13,3.8c0.48,0.33,1,0.59,1.51,0.84c0.33,0.16,0.67,0.33,0.99,0.52c1.67,0.98,2.87,2.51,4.14,4.13c0.45,0.58,0.91,1.16,1.38,1.71c1.91,2.22,4.24,4.06,6.49,5.83c1.99,1.57,4.05,3.19,5.78,5.06L-109.6,95.62zM-133.6,76.38l-1.65-2.22c-0.35-0.46-0.74-0.99-1.27-1.38l-0.59,0.81c0.41,0.3,0.74,0.74,1.06,1.17l1.65,2.22L-133.6,76.38zM-109.72,91.17c-1.54-1.15-3.13-2.34-4.48-3.73c-0.45-0.46-0.87-0.95-1.3-1.43c-0.22-0.25-0.44-0.5-0.66-0.74c-0.85-0.95-1.77-1.87-2.57-2.68l-3.69-3.73c-1.53-1.54-3.11-3.14-4.94-4.43c-0.29-0.2-0.58-0.4-0.87-0.59c-0.68-0.45-1.33-0.88-1.9-1.41c-0.5-0.46-0.94-0.99-1.4-1.55c-0.16-0.19-0.32-0.39-0.49-0.58c-1.3-1.51-2.79-2.86-4.42-3.99l-0.57,0.82c1.57,1.08,2.99,2.37,4.23,3.82c0.16,0.19,0.32,0.38,0.48,0.57c0.46,0.56,0.94,1.14,1.5,1.65c0.63,0.58,1.34,1.05,2.02,1.5c0.28,0.19,0.57,0.38,0.85,0.57c1.76,1.24,3.31,2.8,4.8,4.31l3.69,3.73c0.8,0.81,1.71,1.72,2.54,2.64c0.22,0.24,0.43,0.49,0.65,0.73c0.44,0.5,0.87,1,1.33,1.47c1.4,1.44,3.03,2.66,4.6,3.84L-109.72,91.17zM-109.87,86.77c-4.17-3.87-8.48-7.88-13.17-11.31l-0.27-0.2c-0.65-0.48-1.33-0.97-1.92-1.52c-0.61-0.58-1.14-1.23-1.7-1.92c-0.55-0.68-1.11-1.38-1.77-2c-0.9-0.86-1.94-1.54-2.94-2.2c-0.44-0.29-0.87-0.57-1.3-0.87c-1.69-1.2-2.7-2.34-3.16-3.6l-0.94,0.35c0.71,1.91,2.35,3.24,3.53,4.07c0.43,0.31,0.88,0.6,1.33,0.89c1.01,0.66,1.97,1.29,2.8,2.08c0.6,0.58,1.13,1.22,1.68,1.9c0.55,0.68,1.13,1.39,1.79,2.02c0.63,0.6,1.34,1.11,2.02,1.61l0.27,0.2c4.64,3.4,8.93,7.38,13.08,11.23L-109.87,86.77zM-109.31,83.14c-2.41-1.82-4.68-3.91-6.87-5.92l-2.64-2.42c-0.92-0.84-1.86-1.71-2.68-2.65l-0.37-0.44c-0.33-0.39-0.67-0.8-1.06-1.16c-0.82-0.77-1.8-1.33-2.74-1.87c-1.13-0.64-2.2-1.25-2.97-2.18c-0.2-0.25-0.38-0.51-0.56-0.78c-0.18-0.26-0.36-0.53-0.56-0.78c-0.58-0.73-1.31-1.31-2.01-1.86l-4.77-3.79l-0.62,0.78l4.77,3.79c0.66,0.52,1.34,1.06,1.85,1.7c0.18,0.23,0.35,0.47,0.51,0.71c0.2,0.29,0.4,0.58,0.62,0.85c0.89,1.07,2.08,1.75,3.24,2.41c0.94,0.53,1.82,1.04,2.55,1.73c0.35,0.33,0.65,0.69,0.98,1.08c0.13,0.15,0.25,0.3,0.38,0.45c0.86,0.99,1.83,1.88,2.77,2.74l2.64,2.42c2.21,2.03,4.5,4.13,6.94,5.98L-109.31,83.14zM-109.81,77.55c-3.25-3.56-6.89-6.81-10.41-9.96L-123,65.1c-1.76-1.58-3.59-3.21-5.44-4.78c-1.88-1.59-3.83-3.16-5.86-4.7c-0.8-0.61-1.63-1.24-2.19-2.04l-0.82,0.57c0.65,0.93,1.54,1.6,2.48,2.31c1.95,1.48,3.88,3.03,5.75,4.62c1.84,1.56,3.66,3.19,5.42,4.76l2.78,2.49c3.5,3.13,7.12,6.37,10.34,9.89L-109.81,77.55zM-109.73,73.31c-2.18-1.3-4.12-2.94-5.76-4.88l-0.3-0.36c-0.39-0.47-0.78-0.95-1.25-1.37c-0.45-0.41-0.95-0.74-1.44-1.07l-2.7-1.81c-0.29-0.2-0.61-0.36-0.93-0.53c-0.35-0.18-0.68-0.35-0.96-0.56c-0.96-0.72-1.85-1.7-2.71-2.64c-0.51-0.56-1.01-1.11-1.52-1.61c-2.96-2.89-6.07-5.7-9.22-8.36l-0.64,0.76c3.14,2.65,6.22,5.44,9.17,8.31c0.5,0.49,0.99,1.02,1.48,1.57c0.89,0.98,1.81,1.99,2.84,2.77c0.35,0.26,0.73,0.46,1.11,0.65c0.28,0.15,0.57,0.29,0.83,0.47l2.7,1.81c0.47,0.32,0.92,0.62,1.32,0.98c0.42,0.37,0.77,0.81,1.15,1.27l0.3,0.37c1.71,2.03,3.73,3.74,6.02,5.1L-109.73,73.31zM-109.67,70.03l-17.92-16.85c-3-2.82-6.09-5.73-9.35-8.38l-0.63,0.78c3.22,2.63,6.31,5.53,9.29,8.33l17.92,16.85L-109.67,70.03zM-109.64,75.89c-1.51-1.76-3.16-3.42-4.92-4.94l-0.4-0.34c-0.35-0.3-0.71-0.6-1.05-0.92c-0.47-0.43-0.91-0.89-1.36-1.35c-0.71-0.74-1.44-1.5-2.28-2.15c-0.23-0.18-0.46-0.35-0.7-0.52c-0.65-0.47-1.26-0.92-1.7-1.51l-0.81,0.59c0.53,0.72,1.23,1.23,1.91,1.73c0.23,0.16,0.45,0.33,0.67,0.5c0.78,0.61,1.46,1.31,2.17,2.06c0.46,0.47,0.91,0.95,1.4,1.39c0.35,0.33,0.71,0.64,1.08,0.95l0.39,0.34c1.72,1.49,3.34,3.11,4.81,4.84L-109.64,75.89zM-109.78,65.93c-3.15-2.89-6.47-5.66-9.89-8.24l-0.26-0.19c-0.83-0.62-1.69-1.27-2.44-1.99c-0.67-0.64-1.28-1.38-1.88-2.09c-0.72-0.85-1.46-1.74-2.32-2.5c-0.78-0.69-1.66-1.29-2.5-1.86c-1.39-0.94-2.69-1.82-3.6-3.1c-0.26-0.37-0.49-0.77-0.72-1.2c-0.23-0.42-0.47-0.85-0.75-1.25c-0.51-0.74-1.38-1.66-2.6-1.83l-0.14,0.99c0.86,0.13,1.52,0.84,1.92,1.42c0.25,0.37,0.47,0.76,0.7,1.17c0.24,0.43,0.48,0.87,0.78,1.29c1.01,1.43,2.46,2.41,3.85,3.35c0.82,0.55,1.67,1.13,2.4,1.78c0.81,0.71,1.52,1.57,2.21,2.4c0.61,0.73,1.25,1.49,1.95,2.17c0.79,0.76,1.68,1.43,2.53,2.07l0.26,0.19c3.39,2.56,6.69,5.31,9.82,8.17L-109.78,65.93zM-109.75,62.77c-1.89-1.64-3.84-3.34-5.98-4.73c-0.24-0.16-0.49-0.31-0.73-0.46c-0.67-0.42-1.3-0.81-1.88-1.28c-0.7-0.56-1.31-1.22-1.95-1.91c-0.41-0.44-0.82-0.88-1.26-1.3c-0.63-0.6-1.31-1.16-1.97-1.69c-0.41-0.33-0.81-0.66-1.21-1c-1.38-1.19-2.65-2.56-3.88-3.89c-1.54-1.66-3.14-3.38-4.99-4.8c-0.23-0.17-0.46-0.34-0.69-0.51c-0.83-0.61-1.61-1.18-2.2-1.93l-0.79,0.62c0.68,0.86,1.55,1.5,2.39,2.12c0.23,0.17,0.45,0.33,0.67,0.5c1.78,1.36,3.35,3.05,4.86,4.68c1.25,1.35,2.54,2.74,3.96,3.96c0.4,0.35,0.82,0.69,1.24,1.02c0.64,0.52,1.31,1.06,1.91,1.64c0.42,0.4,0.82,0.83,1.22,1.26c0.64,0.69,1.3,1.4,2.06,2c0.63,0.51,1.31,0.93,1.98,1.35c0.24,0.15,0.48,0.3,0.72,0.46c2.09,1.35,4.01,3.03,5.87,4.64L-109.75,62.77zM-109.56,57.97c-0.82-1.22-1.95-2.13-3.04-2.96c-1.59-1.21-3.26-2.37-4.95-3.44c-0.39-0.24-0.78-0.48-1.17-0.73c-1.45-0.9-2.95-1.82-4.26-2.93c-0.75-0.63-1.46-1.35-2.15-2.04l-0.45-0.45c-3.52-3.51-7.37-6.73-11.46-9.57l-0.57,0.82c4.04,2.8,7.84,5.98,11.32,9.45l0.45,0.45c0.7,0.71,1.43,1.44,2.21,2.1c1.37,1.16,2.9,2.1,4.38,3.02c0.39,0.24,0.77,0.48,1.16,0.72c1.67,1.05,3.31,2.19,4.88,3.39c1.02,0.78,2.08,1.63,2.81,2.72L-109.56,57.97zM-109.45,52.28c-3.82-2.61-7.32-5.78-10.71-8.85c-2.71-2.45-5.51-4.99-8.46-7.24c-0.32-0.25-0.65-0.49-0.98-0.73c-1.19-0.89-2.42-1.8-3.48-2.84c-0.38-0.37-0.74-0.76-1.11-1.15c-0.79-0.85-1.61-1.72-2.6-2.41l-0.57,0.82c0.9,0.63,1.65,1.42,2.44,2.27c0.37,0.4,0.75,0.8,1.14,1.18c1.11,1.08,2.37,2.02,3.58,2.93c0.32,0.24,0.65,0.48,0.97,0.73c2.92,2.23,5.71,4.75,8.4,7.18c3.41,3.09,6.94,6.28,10.81,8.94L-109.45,52.28zM-109.61,50.16c-0.77-0.5-1.35-1.24-1.96-2.02c-0.19-0.25-0.39-0.5-0.59-0.73c-2.02-2.43-4.73-4.12-7.35-5.75c-2-1.25-4.08-2.55-5.8-4.16c-0.49-0.46-0.95-0.94-1.42-1.42c-0.36-0.38-0.72-0.75-1.1-1.12c-1.01-0.98-2.1-1.89-3.17-2.76l-5.65-4.65l-0.64,0.77l5.66,4.66c1.04,0.86,2.13,1.75,3.1,2.7c0.37,0.36,0.72,0.73,1.08,1.09c0.48,0.5,0.95,0.99,1.46,1.46c1.8,1.67,3.91,2.99,5.95,4.27c2.67,1.67,5.19,3.24,7.11,5.55c0.19,0.23,0.38,0.47,0.57,0.71c0.64,0.81,1.29,1.65,2.2,2.24L-109.61,50.16zM-109.8,46.11c-2.91-2.74-6-5.35-9.17-7.79l-0.21-0.16c-0.68-0.52-1.39-1.06-2.01-1.66c-0.35-0.34-0.68-0.7-1.01-1.06c-0.38-0.41-0.77-0.84-1.19-1.23c-1.19-1.11-2.6-1.92-3.96-2.72c-1.47-0.86-2.87-1.66-4.01-2.81c-0.52-0.52-0.97-1.09-1.45-1.7c-0.33-0.42-0.66-0.84-1.02-1.25c-0.9-1.02-1.94-1.91-3.08-2.64l-0.54,0.84c1.07,0.68,2.03,1.51,2.87,2.46c0.34,0.39,0.66,0.79,0.98,1.2c0.47,0.6,0.97,1.23,1.53,1.79c1.23,1.23,2.75,2.11,4.21,2.96c1.32,0.76,2.68,1.55,3.78,2.58c0.39,0.37,0.75,0.76,1.13,1.18c0.34,0.38,0.69,0.75,1.05,1.1c0.66,0.64,1.39,1.19,2.1,1.73l0.2,0.16c3.15,2.41,6.21,5.01,9.1,7.72L-109.8,46.11zM-110.03,41.75c-2.32-2.44-4.72-4.96-7.7-6.73c-0.46-0.28-0.94-0.53-1.41-0.79c-0.64-0.35-1.31-0.7-1.92-1.1c-0.84-0.55-1.63-1.21-2.39-1.85l-0.08-0.07c-4.13-3.47-8.39-6.9-12.67-10.21l-0.61,0.79c4.26,3.3,8.51,6.72,12.63,10.18l0.08,0.07c0.79,0.66,1.6,1.34,2.48,1.92c0.65,0.43,1.33,0.79,2,1.15c0.46,0.25,0.92,0.5,1.38,0.76c2.86,1.7,5.21,4.17,7.49,6.56L-110.03,41.75zM-110.11,37.93c-0.47-0.58-0.98-1.13-1.51-1.66c-0.72-0.71-1.47-1.35-2.25-2.01c-2.1-1.78-4.24-3.52-6.37-5.27c-5.21-4.26-10.59-8.66-15.41-13.49c-0.44-0.44-0.82-0.85-0.94-1.33l-0.97,0.24c0.19,0.78,0.78,1.37,1.2,1.79c4.86,4.86,10.26,9.28,15.49,13.55c2.13,1.74,4.26,3.48,6.36,5.26c0.76,0.64,1.5,1.28,2.19,1.96c0.5,0.5,0.99,1.03,1.44,1.58L-110.11,37.93zM-109.76,35.43c-2.37-2.15-4.98-4.06-7.74-5.68c-0.31-0.18-0.62-0.36-0.92-0.53c-0.64-0.37-1.28-0.73-1.91-1.13c-1.22-0.78-2.37-1.7-3.41-2.72l-0.7,0.71c1.09,1.06,2.29,2.02,3.57,2.84c0.64,0.41,1.29,0.78,1.95,1.16c0.31,0.17,0.61,0.35,0.92,0.53c2.7,1.58,5.25,3.45,7.57,5.56L-109.76,35.43zM-109.72,32.27c-1.48-2.2-3.77-3.58-5.99-4.91c-1.19-0.71-2.41-1.45-3.49-2.3c-1.43-1.13-2.67-2.54-3.88-3.9c-0.95-1.07-1.92-2.18-3-3.16c-1.46-1.34-3.11-2.48-4.71-3.57c-0.96-0.66-1.96-1.34-2.9-2.06c-1.09-0.84-2.29-1.87-2.9-3.21l-0.91,0.41c0.7,1.54,2.01,2.68,3.2,3.59c0.96,0.73,1.96,1.42,2.94,2.09c1.57,1.08,3.19,2.19,4.6,3.48c1.04,0.95,2,2.04,2.93,3.09c1.23,1.39,2.51,2.83,4,4.02c1.12,0.89,2.38,1.65,3.59,2.37c2.22,1.33,4.31,2.59,5.67,4.61L-109.72,32.27zM-109.62,27.29c-1.44-1.71-3.1-3.21-4.93-4.48c-0.4-0.27-0.8-0.53-1.21-0.8c-0.86-0.56-1.76-1.13-2.53-1.81c-0.44-0.39-0.86-0.83-1.27-1.25c-0.2-0.21-0.4-0.42-0.61-0.62c-2.22-2.22-4.87-3.97-7.43-5.67c-2.24-1.48-4.55-3.01-6.54-4.84c-0.85-0.78-1.77-1.74-2.14-2.91l-0.95,0.3c0.44,1.4,1.47,2.48,2.42,3.35c2.05,1.88,4.39,3.43,6.66,4.93c2.52,1.67,5.13,3.4,7.28,5.55c0.2,0.2,0.4,0.41,0.6,0.61c0.42,0.44,0.86,0.89,1.33,1.31c0.83,0.72,1.75,1.32,2.64,1.9c0.4,0.26,0.79,0.51,1.18,0.78c1.76,1.21,3.36,2.66,4.73,4.3L-109.62,27.29zM-109.75,23.52c-2.21-1.31-4.05-3.25-5.83-5.12l-0.64-0.67c-6.18-6.46-13.1-12.23-20.57-17.13l-0.55,0.84c7.41,4.86,14.27,10.58,20.4,16.99l0.64,0.67c1.83,1.92,3.71,3.91,6.04,5.3L-109.75,23.52zM-109.51,18.42l-3.47-3.51c-0.67-0.68-1.36-1.38-2.13-1.99c-0.46-0.37-0.94-0.7-1.43-1.04c-0.35-0.24-0.7-0.48-1.04-0.74c-1.25-0.94-2.37-2.07-3.46-3.17c-0.75-0.76-1.53-1.54-2.15-2.41c-0.19-0.27-0.36-0.55-0.54-0.82c-0.18-0.29-0.37-0.58-0.56-0.86c-1.4-1.99-3.42-3.38-5.37-4.72c-1.51-1.04-3.07-2.12-4.3-3.45l-0.73,0.68c1.31,1.42,2.92,2.53,4.47,3.6c1.96,1.35,3.82,2.63,5.12,4.48c0.19,0.27,0.36,0.54,0.54,0.81c0.18,0.29,0.37,0.58,0.57,0.86c0.67,0.94,1.47,1.75,2.25,2.54c1.11,1.12,2.26,2.28,3.57,3.26c0.35,0.26,0.71,0.51,1.07,0.76c0.47,0.32,0.93,0.64,1.37,1c0.72,0.58,1.39,1.25,2.04,1.91l3.47,3.51L-109.51,18.42zM-109.61,14.78c-6.66-6.28-13.32-12.72-19.79-19.13l-0.7,0.71c6.48,6.41,13.15,12.86,19.81,19.15L-109.61,14.78zM-109.77,9.86c-4.18-5.2-8.97-9.91-14.23-14.01l-0.62,0.79c5.2,4.06,9.93,8.72,14.07,13.85L-109.77,9.86zM-109.69,4.81c-1.21-1.24-2.59-2.34-3.93-3.4c-2.21-1.75-4.3-3.4-5.7-5.69l-0.85,0.52c1.49,2.43,3.75,4.22,5.93,5.95c1.31,1.04,2.67,2.11,3.83,3.31L-109.69,4.81zM-109.17-0.11c-1.37-1.63-2.99-3-4.83-4.06l-0.5,0.87c1.74,1.01,3.28,2.3,4.57,3.84L-109.17-0.11zM-109.89-3.77c-0.14-0.1-0.26-0.24-0.33-0.39l-0.91,0.42c0.15,0.32,0.38,0.59,0.66,0.79L-109.89-3.77z'},
        {label: '实心圆', value: 'circle'},
        {label: '圆角矩形', value: 'roundRect'},
        {label: '三角形', value: 'triangle'},
        {label: '菱形', value: 'diamond'},
        {label: 'pin', value: 'pin'},
        {label: 'arrow', value: 'arrow'},
        {label: '直角三角形', value: 'path://m1,153l0,-152l146,152l-146,0z'},
        {label: '五角星', value: 'path://M100,0 L41.22,180.90 L195.10,69.09 L4.89,69.09 L158.77,180.90 z'},
        {label: '南瓜头', value: 'path://M237.062,81.761L237.062,81.761c-12.144-14.24-25.701-20.1-40.68-19.072 c-10.843,0.747-20.938,5.154-30.257,13.127c-9.51-5.843-19.8-9.227-30.859-10.366c0.521-3.197,1.46-6.306,2.85-9.363 c3.458-7.038,8.907-12.741,16.331-17.296c-5.609-3.384-11.227-6.799-16.854-10.279c-16.257,8.104-25.06,20.601-26.463,38.417 c-7.599,1.705-14.685,4.486-21.247,8.437c-9.164-7.677-18.996-11.917-29.496-12.632c-14.819-0.998-28.467,4.787-40.938,18.827 C6.445,96.182,0,114.867,0,136.242c-0.007,6.371,0.674,12.646,2.053,18.738c4.593,22.785,15.398,41.367,32.558,55.344 c15.43,12.773,29.901,18.023,43.362,16.981c7.074-0.561,13.624-3.977,19.685-10.192c10.534,5.49,20.391,8.217,29.561,8.203 c9.856-0.012,20.236-2.953,31.125-8.898c6.227,6.692,12.966,10.346,20.211,10.933c13.795,1.073,28.614-4.111,44.377-16.84 c17.49-14.104,28.043-32.79,31.796-55.485c0.836-5.624,1.272-11.292,1.272-16.966C255.998,115.814,249.707,96.601,237.062,81.761z  M54.795,97.7l40.661,14.496c-4.402,8.811-10.766,13.219-19.06,13.219c-2.542,0-4.917-0.419-7.122-1.274 C58.103,118.38,53.263,109.572,54.795,97.7z M150.613,185.396l-9.156-8.389l-7.619,12.951c-3.391,0.341-6.615,0.514-9.665,0.514 c-4.401,0-8.635-0.263-12.708-0.777l-8.634-14.973l-9.151,9.909c-4.91-2.717-9.15-5.856-12.708-9.413 c-8.81-8.295-13.384-17.959-13.727-28.97c2.877,1.692,7.427,3.461,13.675,5.308l10.636,13.629l9.44-9.852 c4.734,0.702,9.234,1.12,13.466,1.275l10.689,11.498l9.671-11.949c3.559-0.173,7.285-0.515,11.182-1.01l9.924,10.159l10.933-14.227 c5.931-1.351,11.196-2.798,15.771-4.323C179.747,163.538,169.068,176.414,150.613,185.396z M175.258,124.907 c-2.209,0.849-4.66,1.273-7.369,1.273c-8.134,0-14.489-4.415-19.052-13.224l40.905-14.477 C191.105,110.331,186.273,119.141,175.258,124.907z'},
        {label: '五边形', value: 'path://M4.9,17.8c0-1.4,4.5-10.5,5.5-12.4c0-0.1,0.6-1.1,0.9-1.1c0.4,0,0.9,1,0.9,1.1c1.1,2.2,5.4,11,5.4,12.4v17.8c0,1.5-0.6,2.1-1.3,2.1H6.1c-0.7,0-1.3-0.6-1.3-2.1V17.8z'},
        {label: '开关', value: 'path://M8.2,13.6V3.9H6.3v9.7H3.1v14.9h3.3v9.7h1.8v-9.7h3.3V13.6H8.2z M9.7,24.4H4.8v-1.4h4.9V24.4z M9.7,19.1H4.8v-1.4h4.9V19.1z'},
        {label: '圆环', value: 'path://m43.75,145.74l0,0c0,-51.64 41.86,-93.5 93.5,-93.5l0,0c24.8,0 48.58,9.85 66.11,27.38c17.53,17.53 27.38,41.32 27.38,66.11l0,0c0,51.64 -41.86,93.5 -93.5,93.5l0,0c-51.64,0 -93.5,-41.86 -93.5,-93.5zm46.75,0l0,0c0,25.82 20.93,46.75 46.75,46.75c25.82,0 46.75,-20.93 46.75,-46.75c0,-25.82 -20.93,-46.75 -46.75,-46.75l0,0c-25.82,0 -46.75,20.93 -46.75,46.75z'},
        {label: '五边形2', value: 'path://m0.75,72.94l98,-72.19l98,72.19l-37.43,116.81l-121.13,0l-37.43-116.81z'},
        {label: '六边形', value: 'path://m0.75,89.75l43.93,-89l117.14,0l43.93,89l-43.93,89l-117.14,0l-43.93,-89z'},
        {label: '八边形', value: 'path://m0.75,51.71l50.38,-50.96l71.25,0l50.38,50.96l0,72.07l-50.38,50.96l-71.24,0l-50.38,-50.96l0,-72.07z'},
        {label: '梯形', value: 'path://m0.75,199.75l45.19,-199l150.62,0l45.19,199l-241,0z'},
        {label: '聊天泡泡', value: 'path://m0.75,19.83l0,0c0,-10.54 7.54,-19.08 16.84,-19.08l7.66,0l0,0l36.75,0l68.91,0c4.47,0 8.75,2.01 11.91,5.59c3.16,3.58 4.93,8.43 4.93,13.49l0,47.70l0,0l0,28.62l0,0c0,10.54 -7.54,19.08 -16.84,19.08l-68.91,0l-48,48.52l11.26,-48.52l-7.66,0c-9.3,0 -16.84,-8.54 -16.84,-19.08l0,0l0,-28.62l0,0l0,-47.70z'},
        {label: '心形', value: 'path://m67.25,28.9c27.42,-69.1 134.84,0 0,88.85c-134.84,-88.85 -27.42,-157.96 0,-88.85z'},
        {label: '自行车', value: 'path://m43.58,116.95c6.09,-0.08 -5.8,-0.38 -7.9,-0.54c-17.61,-0.45 -32.23,-19.04 -30.33,-37.48c0.38,-18.48 17.13,-34.67 34.57,-32.81c4.54,-2.05 10.98,4.71 13.8,1.48c7.24,-13.55 14.25,-27.24 21.78,-40.61c6.41,-0.97 14.05,-1.72 20.29,0.12c2.88,4.82 -2.36,6.13 -5.63,5.39c-3.65,0 -7.3,0 -10.96,0c-2.64,5.12 -5.36,10.2 -8.06,15.28c15.34,0 30.69,0 46.03,0c0.34,-1.73 4.22,-5.46 0.78,-5.06c-6.24,-0.83 -2.34,-8.49 2.28,-6.31c6.48914,0.25308 13.20766,-0.67895 19.50206,0.70182c3.36238,7.16234 -6.35973,5.62579 -10.52726,5.7017c-3.08476,-1.06863 -3.72403,2.20441 -4.94539,4.44401c-4.95197,5.38381 -1.87401,11.05805 1.4542,16.30639c1.22079,2.38758 2.09047,5.70127 5.06114,3.47036c6.05792,-1.41288 12.66217,-1.46412 18.69013,0.18793c12.59601,3.97191 22.69543,16.36734 23.54097,30.40867c0.76298,8.62472 -0.97418,17.51478 -6.03216,24.47249c-5.86651,8.9185 -15.38712,13.80195 -25.40294,14.79258m-7.8526,0.08706c-9.13112,-2.48705 -17.5498,-8.27307 -22.43059,-17.00834c-3.19408,-4.36623 -3.60932,-11.12646 -5.30703,-15.50631c-4.47763,-0.06218 -8.95526,-0.12437 -13.4329,-0.18654c-9.06892,-15.48468 -17.06239,-31.67911 -25.81044,-47.37965c-1.70523,5.37502 -11.39945,12.68778 -6.04675,17.63558c13.43349,11.96359 15.22243,35.33174 3.73255,49.4181c-5.26554,6.26497 -12.56998,10.58229 -20.07868,13.02276m0.57674,-8.51889c14.48981,-3.34906 23.74909,-21.08171 18.73723,-35.87066c-1.54888,-4.81666 -5.8106,-12.51082 -9.57469,-12.58967c-4.0124,7.35283 -7.62202,14.96893 -12.01951,22.07538c-9.65648,1.80282 -0.80942,-10.67662 1.23383,-14.9172c2.19065,-5.1739 10.14576,-13.54354 0.1244,-13.41962c-7.03533,-0.74307 -14.51197,-0.02449 -20.20328,4.93178c-12.21388,8.57867 -14.52558,28.19993 -5.27609,40.02793c6.26165,8.61688 17.07483,12.28033 26.9781,9.76206l0.00001,-0.00001l0,0.00001zm101.37966,-0.00213c12.36755,-3.08417 21.26741,-16.57559 19.66657,-29.96559c-0.84666,-14.88069 -14.82871,-26.91539 -28.72931,-24.9153c-10.41634,-1.04634 -0.4439,9.10331 1.04499,14.03757c1.41646,5.23929 9.21941,11.67435 4.86304,16.78375c-9.77085,0.43445 -19.78127,-0.30509 -29.52529,0.7406c1.7501,13.71381 13.97787,25.05808 27.1725,24.00866c1.85169,-0.01603 3.7123,-0.1823 5.5075,-0.6897l-0.00001,0l0.00001,0.00001zm-39.916,-30.64793c1.17687,-10.73006 6.90731,-20.49047 15.26463,-26.59765c0.49376,-2.63208 -4.56668,-14.75507 -6.41961,-6.30321c-5.71936,11.03387 -11.46895,22.05294 -17.01306,33.18684c2.65595,0.06818 5.63324,0.56041 8.16804,-0.28597l0,-0.00001zm29.8543,-0.53218c-3.29693,-6.57841 -6.66706,-13.11734 -10.11307,-19.6091c-6.91281,3.86916 -11.46056,12.05733 -12.53558,20.23013c7.54791,-0.17077 15.22243,0.4186 22.6683,-0.42679l-0.01962,-0.19425l0,0l-0.00003,0.00001zm-32.33441,-23.72825c3.2516,-6.36969 6.56492,-12.70582 9.71609,-19.13207c-13.70226,-0.32603 -27.43561,-0.39745 -41.13324,0.06891c7.03571,12.83417 13.39208,26.16548 21.08494,38.55c3.72,-6.07 6.88,-13.06 10.33,-19.48l0,0l0,0z'},
        {label: '公交车', value: 'path://M1024 476.279467c0 0 0 33.4848 0 41.591467 0 72.362667 0 136.6528 0 136.6528 0 15.479467-12.100267 28.040533-27.016533 28.040533l-41.284267 0c0-56.610133-45.8752-102.5024-102.4512-102.5024s-102.4512 45.8752-102.4512 102.5024L290.304 682.564267c-0.017067-56.610133-45.8752-102.5024-102.468267-102.5024-56.558933 0-102.434133 45.8752-102.4512 102.5024L27.0336 682.564267c-14.916267 0-27.016533-12.544-27.016533-28.040533L0.017067 318.173867C0.017067 290.423467 17.988267 273.066667 44.100267 273.066667c0 0 811.3152 0 844.032 0s98.4576 43.281067 124.125867 101.870933C1025.655467 406.289067 1024 476.279467 1024 476.279467zM170.786133 324.317867 78.574933 324.317867c-15.086933 0-27.323733 12.219733-27.323733 27.306667l0 81.834667c0 15.086933 12.2368 27.2896 27.323733 27.2896l92.2112 0L170.786133 324.317867zM324.471467 324.317867l-119.534933 0 0 136.413867 119.534933 0L324.471467 324.317867zM477.610667 324.317867l-119.005867 0 0 136.413867 119.005867 0L477.610667 324.317867zM631.210667 324.317867l-119.005867 0 0 136.413867 119.005867 0L631.210667 324.317867zM784.896 324.317867l-119.534933 0 0 136.413867 119.534933 0L784.896 324.317867zM784.8448 524.919467c0-7.0144-7.645867-12.6976-17.083733-12.6976s-17.066667 5.6832-17.066667 12.6976l0 25.361067c0 7.0144 7.6288 12.6976 17.066667 12.6976s17.083733-5.6832 17.083733-12.6976L784.8448 524.919467zM966.024533 404.155733c-11.008-46.728533-71.3728-79.837867-88.1152-79.837867-41.0112 0-58.845867 0-58.845867 0l0 136.413867L971.741867 460.8C971.741867 460.8 974.848 441.719467 966.024533 404.155733zM187.835733 614.2464c37.717333 0 68.3008 30.600533 68.3008 68.352 0 37.7344-30.583467 68.334933-68.3008 68.334933-37.7344 0-68.3008-30.600533-68.3008-68.334933C119.534933 644.846933 150.101333 614.2464 187.835733 614.2464zM853.265067 614.2464c37.717333 0 68.3008 30.600533 68.3008 68.352 0 37.7344-30.583467 68.334933-68.3008 68.334933-37.7344 0-68.317867-30.600533-68.317867-68.334933C784.9472 644.846933 815.530667 614.2464 853.265067 614.2464z'},
        {label: '飞机', value: 'path://M1705.06,1318.313v-89.254l-319.9-221.799l0.073-208.063c0.521-84.662-26.629-121.796-63.961-121.491c-37.332-0.305-64.482,36.829-63.961,121.491l0.073,208.063l-319.9,221.799v89.254l330.343-157.288l12.238,241.308l-134.449,92.931l0.531,42.034l175.125-42.917l175.125,42.917l0.531-42.034l-134.449-92.931l12.238-241.308L1705.06,1318.313z'},
        {label: '火箭', value: 'path://M22 2l-10 10h-6l-6 8c0 0 6.357-1.77 10.065-0.94l-10.065 12.94 13.184-10.255c1.839 4.208-1.184 10.255-1.184 10.255l8-6v-6l10-10 2-10-10 2z'},
        {label: '空心人', value: 'path://M917.965523 917.331585c0 22.469758-17.891486 40.699957-39.913035 40.699957-22.058388 0-39.913035-18.2302-39.913035-40.699957l-0.075725-0.490164-1.087774 0c-18.945491-157.665903-148.177807-280.296871-306.821991-285.4748-3.412726 0.151449-6.751774 0.562818-10.240225 0.562818-3.450589 0-6.789637-0.410346-10.202363-0.524956-158.606321 5.139044-287.839661 127.806851-306.784128 285.436938l-1.014096 0 0.075725 0.490164c0 22.469758-17.854647 40.699957-39.913035 40.699957s-39.915082-18.2302-39.915082-40.699957l-0.373507-3.789303c0-6.751774 2.026146-12.903891 4.91494-18.531052 21.082154-140.712789 111.075795-258.241552 235.432057-312.784796C288.420387 530.831904 239.989351 444.515003 239.989351 346.604042c0-157.591201 125.33352-285.361213 279.924387-285.361213 154.62873 0 279.960203 127.770012 279.960203 285.361213 0 97.873098-48.391127 184.15316-122.103966 235.545644 124.843356 54.732555 215.099986 172.863023 235.808634 314.211285 2.437515 5.290493 4.01443 10.992355 4.01443 17.181311L917.965523 917.331585zM719.822744 346.679767c0-112.576985-89.544409-203.808826-199.983707-203.808826-110.402459 0-199.944821 91.232864-199.944821 203.808826s89.542362 203.808826 199.944821 203.808826C630.278335 550.488593 719.822744 459.256752 719.822744 346.679767z'},
        {label: '实心人', value: 'path://path://M621.855287 587.643358C708.573965 540.110571 768 442.883654 768 330.666667 768 171.608659 648.609267 42.666667 501.333333 42.666667 354.057399 42.666667 234.666667 171.608659 234.666667 330.666667 234.666667 443.22333 294.453005 540.699038 381.59961 588.07363 125.9882 652.794383 21.333333 855.35859 21.333333 1002.666667L486.175439 1002.666667 1002.666667 1002.666667C1002.666667 815.459407 839.953126 634.458526 621.855287 587.643358Z'},
        {label: '垃圾箱', value: 'path://M6 32h20l2-22h-24zM20 4v-4h-8v4h-10v6l2-2h24l2 2v-6h-10zM18 4h-4v-2h4v2z'},
        {label: '闪电', value: 'path://M12 0l-12 16h12l-8 16 28-20h-16l12-12z'},
        {label: '鹅毛笔', value: 'path://M0 32c4-12 14.469-32 32-32-8.219 6.594-12 22-18 22s-6 0-6 0l-6 10h-2z'},
        {label: '音乐', value: 'path://M30 0h2v23c0 2.761-3.134 5-7 5s-7-2.239-7-5c0-2.761 3.134-5 7-5 1.959 0 3.729 0.575 5 1.501v-11.501l-16 3.556v15.444c0 2.761-3.134 5-7 5s-7-2.239-7-5c0-2.761 3.134-5 7-5 1.959 0 3.729 0.575 5 1.501v-19.501l18-4z'},
        {label: '铁路', value: 'path://M22 32h10l-8-32h-6l1 8h-6l1-8h-6l-8 32h10l1-8h10l1 8zM11.5 20l1-8h7l1 8h-9z'},
        {label: '沙漏', value: 'path://M22.781 16c4.305-2.729 7.219-7.975 7.219-14 0-0.677-0.037-1.345-0.109-2h-27.783c-0.072 0.655-0.109 1.323-0.109 2 0 6.025 2.914 11.271 7.219 14-4.305 2.729-7.219 7.975-7.219 14 0 0.677 0.037 1.345 0.109 2h27.783c0.072-0.655 0.109-1.323 0.109-2 0-6.025-2.914-11.271-7.219-14zM5 30c0-5.841 2.505-10.794 7-12.428v-3.143c-4.495-1.634-7-6.587-7-12.428v0h22c0 5.841-2.505 10.794-7 12.428v3.143c4.495 1.634 7 6.587 7 12.428h-22zM19.363 20.925c-2.239-1.27-2.363-2.918-2.363-3.918v-2.007c0-1 0.119-2.654 2.367-3.927 1.203-0.699 2.244-1.761 3.033-3.073h-12.799c0.79 1.313 1.832 2.376 3.036 3.075 2.239 1.27 2.363 2.918 2.363 3.918v2.007c0 1-0.119 2.654-2.367 3.927-2.269 1.318-3.961 3.928-4.472 7.073h15.677c-0.511-3.147-2.204-5.758-4.475-7.075z'},
        //{label: '', value: ''},
      ]
      //150种legend-----图例，源自--> https://www.makeapie.com/editor.html?c=xH1x8o9Kfx
      /*iconArray:[//
        'circle', //实心圆
        'rect', //矩形
        'roundRect', //圆角矩形
        'triangle', //三角形
        'diamond', //菱形
        'pin', //
        'arrow', //箭头
        'line', //line
        'square', //正方形
        'emptyCircle', //空心圆
        'emptyRect', //空心矩形
        'emptyTriangle',
        'emptyPin',
        'emptyArrow',
        'emptyDiamond',
        'path://m1,153l0,-152l146,152l-146,0z', //直角三角形
        'path://M100,0 L41.22,180.90 L195.10,69.09 L4.89,69.09 L158.77,180.90 z', //五角星
        'path://M237.062,81.761L237.062,81.761c-12.144-14.24-25.701-20.1-40.68-19.072 c-10.843,0.747-20.938,5.154-30.257,13.127c-9.51-5.843-19.8-9.227-30.859-10.366c0.521-3.197,1.46-6.306,2.85-9.363 c3.458-7.038,8.907-12.741,16.331-17.296c-5.609-3.384-11.227-6.799-16.854-10.279c-16.257,8.104-25.06,20.601-26.463,38.417 c-7.599,1.705-14.685,4.486-21.247,8.437c-9.164-7.677-18.996-11.917-29.496-12.632c-14.819-0.998-28.467,4.787-40.938,18.827 C6.445,96.182,0,114.867,0,136.242c-0.007,6.371,0.674,12.646,2.053,18.738c4.593,22.785,15.398,41.367,32.558,55.344 c15.43,12.773,29.901,18.023,43.362,16.981c7.074-0.561,13.624-3.977,19.685-10.192c10.534,5.49,20.391,8.217,29.561,8.203 c9.856-0.012,20.236-2.953,31.125-8.898c6.227,6.692,12.966,10.346,20.211,10.933c13.795,1.073,28.614-4.111,44.377-16.84 c17.49-14.104,28.043-32.79,31.796-55.485c0.836-5.624,1.272-11.292,1.272-16.966C255.998,115.814,249.707,96.601,237.062,81.761z  M54.795,97.7l40.661,14.496c-4.402,8.811-10.766,13.219-19.06,13.219c-2.542,0-4.917-0.419-7.122-1.274 C58.103,118.38,53.263,109.572,54.795,97.7z M150.613,185.396l-9.156-8.389l-7.619,12.951c-3.391,0.341-6.615,0.514-9.665,0.514 c-4.401,0-8.635-0.263-12.708-0.777l-8.634-14.973l-9.151,9.909c-4.91-2.717-9.15-5.856-12.708-9.413 c-8.81-8.295-13.384-17.959-13.727-28.97c2.877,1.692,7.427,3.461,13.675,5.308l10.636,13.629l9.44-9.852 c4.734,0.702,9.234,1.12,13.466,1.275l10.689,11.498l9.671-11.949c3.559-0.173,7.285-0.515,11.182-1.01l9.924,10.159l10.933-14.227 c5.931-1.351,11.196-2.798,15.771-4.323C179.747,163.538,169.068,176.414,150.613,185.396z M175.258,124.907 c-2.209,0.849-4.66,1.273-7.369,1.273c-8.134,0-14.489-4.415-19.052-13.224l40.905-14.477 C191.105,110.331,186.273,119.141,175.258,124.907z', //南瓜头
        'path://M4.9,17.8c0-1.4,4.5-10.5,5.5-12.4c0-0.1,0.6-1.1,0.9-1.1c0.4,0,0.9,1,0.9,1.1c1.1,2.2,5.4,11,5.4,12.4v17.8c0,1.5-0.6,2.1-1.3,2.1H6.1c-0.7,0-1.3-0.6-1.3-2.1V17.8z', //
        'path://M8.2,13.6V3.9H6.3v9.7H3.1v14.9h3.3v9.7h1.8v-9.7h3.3V13.6H8.2z M9.7,24.4H4.8v-1.4h4.9V24.4z M9.7,19.1H4.8v-1.4h4.9V19.1z', //
        'path://m43.75,145.74l0,0c0,-51.64 41.86,-93.5 93.5,-93.5l0,0c24.8,0 48.58,9.85 66.11,27.38c17.53,17.53 27.38,41.32 27.38,66.11l0,0c0,51.64 -41.86,93.5 -93.5,93.5l0,0c-51.64,0 -93.5,-41.86 -93.5,-93.5zm46.75,0l0,0c0,25.82 20.93,46.75 46.75,46.75c25.82,0 46.75,-20.93 46.75,-46.75c0,-25.82 -20.93,-46.75 -46.75,-46.75l0,0c-25.82,0 -46.75,20.93 -46.75,46.75z', //圆环
        'path://m0.75,72.94l98,-72.19l98,72.19l-37.43,116.81l-121.13,0l-37.43-116.81z', //五边形
        'path://m0.75,89.75l43.93,-89l117.14,0l43.93,89l-43.93,89l-117.14,0l-43.93,-89z', //六边形
        'path://m0.75,51.71l50.38,-50.96l71.25,0l50.38,50.96l0,72.07l-50.38,50.96l-71.24,0l-50.38,-50.96l0,-72.07z', //八边形
        'path://m0.75,199.75l45.19,-199l150.62,0l45.19,199l-241,0z', //梯形
        'path://m0.75,19.83l0,0c0,-10.54 7.54,-19.08 16.84,-19.08l7.66,0l0,0l36.75,0l68.91,0c4.47,0 8.75,2.01 11.91,5.59c3.16,3.58 4.93,8.43 4.93,13.49l0,47.70l0,0l0,28.62l0,0c0,10.54 -7.54,19.08 -16.84,19.08l-68.91,0l-48,48.52l11.26,-48.52l-7.66,0c-9.3,0 -16.84,-8.54 -16.84,-19.08l0,0l0,-28.62l0,0l0,-47.70z', //聊天泡泡
        'path://m67.25,28.9c27.42,-69.1 134.84,0 0,88.85c-134.84,-88.85 -27.42,-157.96 0,-88.85z', //心形
        'path://m43.58,116.95c6.09,-0.08 -5.8,-0.38 -7.9,-0.54c-17.61,-0.45 -32.23,-19.04 -30.33,-37.48c0.38,-18.48 17.13,-34.67 34.57,-32.81c4.54,-2.05 10.98,4.71 13.8,1.48c7.24,-13.55 14.25,-27.24 21.78,-40.61c6.41,-0.97 14.05,-1.72 20.29,0.12c2.88,4.82 -2.36,6.13 -5.63,5.39c-3.65,0 -7.3,0 -10.96,0c-2.64,5.12 -5.36,10.2 -8.06,15.28c15.34,0 30.69,0 46.03,0c0.34,-1.73 4.22,-5.46 0.78,-5.06c-6.24,-0.83 -2.34,-8.49 2.28,-6.31c6.48914,0.25308 13.20766,-0.67895 19.50206,0.70182c3.36238,7.16234 -6.35973,5.62579 -10.52726,5.7017c-3.08476,-1.06863 -3.72403,2.20441 -4.94539,4.44401c-4.95197,5.38381 -1.87401,11.05805 1.4542,16.30639c1.22079,2.38758 2.09047,5.70127 5.06114,3.47036c6.05792,-1.41288 12.66217,-1.46412 18.69013,0.18793c12.59601,3.97191 22.69543,16.36734 23.54097,30.40867c0.76298,8.62472 -0.97418,17.51478 -6.03216,24.47249c-5.86651,8.9185 -15.38712,13.80195 -25.40294,14.79258m-7.8526,0.08706c-9.13112,-2.48705 -17.5498,-8.27307 -22.43059,-17.00834c-3.19408,-4.36623 -3.60932,-11.12646 -5.30703,-15.50631c-4.47763,-0.06218 -8.95526,-0.12437 -13.4329,-0.18654c-9.06892,-15.48468 -17.06239,-31.67911 -25.81044,-47.37965c-1.70523,5.37502 -11.39945,12.68778 -6.04675,17.63558c13.43349,11.96359 15.22243,35.33174 3.73255,49.4181c-5.26554,6.26497 -12.56998,10.58229 -20.07868,13.02276m0.57674,-8.51889c14.48981,-3.34906 23.74909,-21.08171 18.73723,-35.87066c-1.54888,-4.81666 -5.8106,-12.51082 -9.57469,-12.58967c-4.0124,7.35283 -7.62202,14.96893 -12.01951,22.07538c-9.65648,1.80282 -0.80942,-10.67662 1.23383,-14.9172c2.19065,-5.1739 10.14576,-13.54354 0.1244,-13.41962c-7.03533,-0.74307 -14.51197,-0.02449 -20.20328,4.93178c-12.21388,8.57867 -14.52558,28.19993 -5.27609,40.02793c6.26165,8.61688 17.07483,12.28033 26.9781,9.76206l0.00001,-0.00001l0,0.00001zm101.37966,-0.00213c12.36755,-3.08417 21.26741,-16.57559 19.66657,-29.96559c-0.84666,-14.88069 -14.82871,-26.91539 -28.72931,-24.9153c-10.41634,-1.04634 -0.4439,9.10331 1.04499,14.03757c1.41646,5.23929 9.21941,11.67435 4.86304,16.78375c-9.77085,0.43445 -19.78127,-0.30509 -29.52529,0.7406c1.7501,13.71381 13.97787,25.05808 27.1725,24.00866c1.85169,-0.01603 3.7123,-0.1823 5.5075,-0.6897l-0.00001,0l0.00001,0.00001zm-39.916,-30.64793c1.17687,-10.73006 6.90731,-20.49047 15.26463,-26.59765c0.49376,-2.63208 -4.56668,-14.75507 -6.41961,-6.30321c-5.71936,11.03387 -11.46895,22.05294 -17.01306,33.18684c2.65595,0.06818 5.63324,0.56041 8.16804,-0.28597l0,-0.00001zm29.8543,-0.53218c-3.29693,-6.57841 -6.66706,-13.11734 -10.11307,-19.6091c-6.91281,3.86916 -11.46056,12.05733 -12.53558,20.23013c7.54791,-0.17077 15.22243,0.4186 22.6683,-0.42679l-0.01962,-0.19425l0,0l-0.00003,0.00001zm-32.33441,-23.72825c3.2516,-6.36969 6.56492,-12.70582 9.71609,-19.13207c-13.70226,-0.32603 -27.43561,-0.39745 -41.13324,0.06891c7.03571,12.83417 13.39208,26.16548 21.08494,38.55c3.72,-6.07 6.88,-13.06 10.33,-19.48l0,0l0,0z', //自行车
        'path://M1024 476.279467c0 0 0 33.4848 0 41.591467 0 72.362667 0 136.6528 0 136.6528 0 15.479467-12.100267 28.040533-27.016533 28.040533l-41.284267 0c0-56.610133-45.8752-102.5024-102.4512-102.5024s-102.4512 45.8752-102.4512 102.5024L290.304 682.564267c-0.017067-56.610133-45.8752-102.5024-102.468267-102.5024-56.558933 0-102.434133 45.8752-102.4512 102.5024L27.0336 682.564267c-14.916267 0-27.016533-12.544-27.016533-28.040533L0.017067 318.173867C0.017067 290.423467 17.988267 273.066667 44.100267 273.066667c0 0 811.3152 0 844.032 0s98.4576 43.281067 124.125867 101.870933C1025.655467 406.289067 1024 476.279467 1024 476.279467zM170.786133 324.317867 78.574933 324.317867c-15.086933 0-27.323733 12.219733-27.323733 27.306667l0 81.834667c0 15.086933 12.2368 27.2896 27.323733 27.2896l92.2112 0L170.786133 324.317867zM324.471467 324.317867l-119.534933 0 0 136.413867 119.534933 0L324.471467 324.317867zM477.610667 324.317867l-119.005867 0 0 136.413867 119.005867 0L477.610667 324.317867zM631.210667 324.317867l-119.005867 0 0 136.413867 119.005867 0L631.210667 324.317867zM784.896 324.317867l-119.534933 0 0 136.413867 119.534933 0L784.896 324.317867zM784.8448 524.919467c0-7.0144-7.645867-12.6976-17.083733-12.6976s-17.066667 5.6832-17.066667 12.6976l0 25.361067c0 7.0144 7.6288 12.6976 17.066667 12.6976s17.083733-5.6832 17.083733-12.6976L784.8448 524.919467zM966.024533 404.155733c-11.008-46.728533-71.3728-79.837867-88.1152-79.837867-41.0112 0-58.845867 0-58.845867 0l0 136.413867L971.741867 460.8C971.741867 460.8 974.848 441.719467 966.024533 404.155733zM187.835733 614.2464c37.717333 0 68.3008 30.600533 68.3008 68.352 0 37.7344-30.583467 68.334933-68.3008 68.334933-37.7344 0-68.3008-30.600533-68.3008-68.334933C119.534933 644.846933 150.101333 614.2464 187.835733 614.2464zM853.265067 614.2464c37.717333 0 68.3008 30.600533 68.3008 68.352 0 37.7344-30.583467 68.334933-68.3008 68.334933-37.7344 0-68.317867-30.600533-68.317867-68.334933C784.9472 644.846933 815.530667 614.2464 853.265067 614.2464z', //公交车
        'path://M1705.06,1318.313v-89.254l-319.9-221.799l0.073-208.063c0.521-84.662-26.629-121.796-63.961-121.491c-37.332-0.305-64.482,36.829-63.961,121.491l0.073,208.063l-319.9,221.799v89.254l330.343-157.288l12.238,241.308l-134.449,92.931l0.531,42.034l175.125-42.917l175.125,42.917l0.531-42.034l-134.449-92.931l12.238-241.308L1705.06,1318.313z', //飞机
        'path://M24 19.999l-5.713-5.713 13.713-10.286-4-4-17.141 6.858-5.397-5.397c-1.556-1.556-3.728-1.928-4.828-0.828s-0.727 3.273 0.828 4.828l5.396 5.396-6.858 17.143 4 4 10.287-13.715 5.713 5.713v7.999h4l2-6 6-2v-4l-7.999 0z', //飞机
        'path://M22 2l-10 10h-6l-6 8c0 0 6.357-1.77 10.065-0.94l-10.065 12.94 13.184-10.255c1.839 4.208-1.184 10.255-1.184 10.255l8-6v-6l10-10 2-10-10 2z', //火箭
        'path://M917.965523 917.331585c0 22.469758-17.891486 40.699957-39.913035 40.699957-22.058388 0-39.913035-18.2302-39.913035-40.699957l-0.075725-0.490164-1.087774 0c-18.945491-157.665903-148.177807-280.296871-306.821991-285.4748-3.412726 0.151449-6.751774 0.562818-10.240225 0.562818-3.450589 0-6.789637-0.410346-10.202363-0.524956-158.606321 5.139044-287.839661 127.806851-306.784128 285.436938l-1.014096 0 0.075725 0.490164c0 22.469758-17.854647 40.699957-39.913035 40.699957s-39.915082-18.2302-39.915082-40.699957l-0.373507-3.789303c0-6.751774 2.026146-12.903891 4.91494-18.531052 21.082154-140.712789 111.075795-258.241552 235.432057-312.784796C288.420387 530.831904 239.989351 444.515003 239.989351 346.604042c0-157.591201 125.33352-285.361213 279.924387-285.361213 154.62873 0 279.960203 127.770012 279.960203 285.361213 0 97.873098-48.391127 184.15316-122.103966 235.545644 124.843356 54.732555 215.099986 172.863023 235.808634 314.211285 2.437515 5.290493 4.01443 10.992355 4.01443 17.181311L917.965523 917.331585zM719.822744 346.679767c0-112.576985-89.544409-203.808826-199.983707-203.808826-110.402459 0-199.944821 91.232864-199.944821 203.808826s89.542362 203.808826 199.944821 203.808826C630.278335 550.488593 719.822744 459.256752 719.822744 346.679767z', //空心人
        'path://path://M621.855287 587.643358C708.573965 540.110571 768 442.883654 768 330.666667 768 171.608659 648.609267 42.666667 501.333333 42.666667 354.057399 42.666667 234.666667 171.608659 234.666667 330.666667 234.666667 443.22333 294.453005 540.699038 381.59961 588.07363 125.9882 652.794383 21.333333 855.35859 21.333333 1002.666667L486.175439 1002.666667 1002.666667 1002.666667C1002.666667 815.459407 839.953126 634.458526 621.855287 587.643358Z', //实心人
        'path://M54.227,12.611c-0.338-0.336-0.736-0.505-1.196-0.505c-0.229,0-0.712,0.188-1.446,0.559  c-0.735,0.372-1.515,0.786-2.336,1.248c-0.823,0.459-1.797,0.875-2.921,1.247c-1.123,0.371-2.163,0.559-3.12,0.559  c-0.884,0-1.664-0.168-2.336-0.505c-2.229-1.044-4.168-1.823-5.814-2.337c-1.646-0.513-3.416-0.771-5.311-0.771  c-3.272,0-6.999,1.064-11.177,3.188c-0.862,0.43-1.48,0.763-1.88,1.007l-0.397-2.911c0.897-0.779,1.476-1.914,1.476-3.195  c0-2.347-1.902-4.249-4.249-4.249c-2.347,0-4.249,1.902-4.249,4.249c0,1.531,0.818,2.862,2.032,3.61l5.74,42.09  c0.171,1.253,1.243,2.162,2.474,2.162c0.112,0,0.226-0.007,0.341-0.022c1.368-0.188,2.326-1.447,2.139-2.815L19.69,38.303  c4.186-2.077,7.807-3.124,10.853-3.124c1.293,0,2.554,0.193,3.783,0.583c1.23,0.391,2.253,0.815,3.067,1.274  c0.814,0.46,1.775,0.886,2.88,1.274c1.107,0.39,2.2,0.585,3.279,0.585c2.726,0,5.991-1.027,9.796-3.08  c0.478-0.248,0.828-0.492,1.049-0.731c0.221-0.239,0.332-0.579,0.332-1.021V13.806C54.729,13.347,54.562,12.948,54.227,12.611z', //旗子
        'path://M266.048,191.088c50.663,0,92.957,30.761,102.883,71.688c-1.659-0.072-3.339-0.104-5.021-0.104c-55.207,0-99.959,38.572-99.959,86.153c0,7.81,1.204,15.359,3.465,22.554c-0.456,0-0.922,0.011-1.369,0.011c-13.611,0-26.619-2.21-38.559-6.256l-37.043,18.925l10.373-32.126c-24.295-16.517-39.875-42.044-39.875-70.698C160.943,231.442,207.999,191.088,266.048,191.088L266.048,191.088z M360.747,271.463c48.777,0,88.31,33.899,88.31,75.746c0,24.128-13.153,45.62-33.65,59.509l8.132,26.194L393.735,417.5l0.031-0.021c-10.208,3.535-21.349,5.475-33.02,5.475c-48.775,0-88.319-33.909-88.319-75.744C272.428,305.362,311.972,271.463,360.747,271.463L360.747,271.463z M392.864,310.91c6.494,0,11.773,5.287,11.773,11.813c0,6.549-5.279,11.847-11.773,11.847s-11.774-5.298-11.774-11.847C381.09,316.197,386.37,310.91,392.864,310.91L392.864,310.91z M334.513,310.91c6.493,0,11.774,5.287,11.774,11.813c0,6.549-5.281,11.847-11.774,11.847c-6.504,0-11.763-5.298-11.763-11.847C322.75,316.197,328.009,310.91,334.513,310.91L334.513,310.91z M229.523,234.299c8.081,0,14.637,6.58,14.637,14.704c0,8.112-6.556,14.702-14.637,14.702c-8.081,0-14.627-6.59-14.627-14.702C214.896,240.879,221.442,234.299,229.523,234.299L229.523,234.299z M302.055,234.299c8.08,0,14.626,6.58,14.626,14.704c0,8.112-6.546,14.702-14.626,14.702c-8.082,0-14.637-6.59-14.637-14.702C287.418,240.879,293.973,234.299,302.055,234.299L302.055,234.299z', //微信
        'path://M124.302,345.927c0.08,59.373,76.261,95.476,150.779,95.476c97.736,0,162.761-56.793,162.761-101.885 c0-27.233-22.951-42.698-43.563-49.094c-5.053-1.503-8.537-2.54-5.877-9.188c5.73-14.441,6.329-26.901,0.106-35.783 c-11.676-16.662-43.589-15.771-80.184-0.452c0-0.014-11.489,5.026-8.551-4.083c5.625-18.098,4.774-33.243-3.976-42.006 c-19.854-19.854-72.644,0.758-117.922,46.009c-33.815,33.828-53.482,69.679-53.575,100.701V345.927L124.302,345.927z M275.268,420.101c-59.493,5.864-110.848-21.023-114.717-60.092c-3.856-39.055,41.262-75.476,100.754-81.354 c59.493-5.891,110.848,20.997,114.704,60.052C379.865,377.788,334.773,414.209,275.268,420.101L275.268,420.101z M459.185,181.664 c-23.604-26.17-58.416-36.143-90.569-29.308l0,0c-7.433,1.582-12.181,8.909-10.585,16.329c1.583,7.42,8.896,12.181,16.33,10.585 c22.871-4.854,47.604,2.247,64.386,20.837c16.768,18.59,21.329,43.948,14.135,66.168l0.014,0.014 c-2.34,7.233,1.609,14.986,8.856,17.326c7.233,2.327,14.999-1.622,17.34-8.843c0-0.014,0-0.04,0-0.053 C489.17,243.443,482.787,207.807,459.185,181.664L459.185,181.664z M422.936,214.376c-11.489-12.739-28.443-17.579-44.107-14.255 c-6.409,1.356-10.479,7.659-9.109,14.068c1.37,6.383,7.673,10.479,14.056,9.096v0.013c7.646-1.622,15.943,0.731,21.568,6.955 c5.611,6.236,7.128,14.72,4.708,22.18h0.026c-2.021,6.21,1.383,12.898,7.605,14.906c6.237,1.995,12.912-1.396,14.92-7.632 C437.522,244.481,434.451,227.114,422.936,214.376L422.936,214.376z M278.565,349.345c-2.088,3.563-6.688,5.279-10.292,3.79 c-3.537-1.463-4.654-5.439-2.633-8.937c2.074-3.471,6.488-5.173,10.025-3.763C279.257,341.738,280.547,345.768,278.565,349.345 L278.565,349.345z M259.604,373.679c-5.758,9.188-18.085,13.204-27.366,8.976c-9.149-4.175-11.835-14.84-6.091-23.789 c5.691-8.909,17.606-12.885,26.808-9.016C262.289,353.813,265.255,364.41,259.604,373.679L259.604,373.679z M281.225,308.708c-28.311-7.367-60.317,6.741-72.617,31.688c-12.513,25.438-0.412,53.682,28.19,62.923c29.64,9.548,64.56-5.093,76.7-32.552C325.479,343.919,310.519,316.273,281.225,308.708L281.225,308.708z', //微博
        'path://M404.32,355.807c-8.773,2.607-17.837,8.488-24.154,15.163 c-12.469,13.167-19.628,38.858-39.74,43.198c-16.484,3.591-34.486-12.308-40.914-25.328c25.837-27.934,48.791-65.215,65.577-98.464 c9.657-19.173,19.864-41.305,21.948-63.506c2.179-23.071-3.919-40.964-19.534-51.492c-13.284-8.94-30.747-14.788-43.934-19.378 c-16.181,25.498-31.906,51.323-47.189,77.557c6.331,2.583,12.027,4.962,17.905,7.355c8.179,3.32,16.634,5.722,17.905,16.034 c1.131,9.52-3.215,20.5-7.339,30.098c-7.421,17.236-17.173,32.897-30.914,46.11c-6.827,6.561-16.138,14.335-25.229,14.709 c-14.388,0.612-25.34-6.618-34.996-12.035c-15.782,25.611-32.044,51.845-47.205,76.878c15.547,4.85,26.9,13.541,43.949,17.371 c6.566,1.496,17.739,2.278,26.029,0.681c17.547-3.377,33.19-13.938,45.935-25.09c19.836,26.992,60.57,40.933,88.903,15.967 c17.243-15.23,25.243-48.365,48.225-48.002c15.808,0.238,26.347,14.765,30.802,24.147c7.119-1.846,16.319-4.521,23.299-6.481 C466.104,367.456,431.522,347.728,404.32,355.807L404.32,355.807z', //电话
        'path://M164,210.677v33.47l154.656,66.356L468,243.681v-33.004H164L164,210.677z M164,282.255L164,282.255v134.76h304V282.061l-149.012,66.615L164,282.255L164,282.255z', //短信
        'path://M42.677,26.583l15.466-0.022l-2.798,4.447l-9.855-0.027 L42.677,26.583L42.677,26.583z M45.562,31.912h9.769c-0.023,2.716,0.075,5.745-3.027,7.152c-1.931,0.875-3.87,0.294-4.639-0.339 C45.447,36.907,45.579,34.432,45.562,31.912L45.562,31.912z M35.709,46.547l0.152,26.248c0,0-0.305,2.039,1.091-0.605l4.001-7.576 c0.297-0.561-0.01-10.404,0.137-9.811c0.229,0.949,0.881,6.957,1.055,6.957l1.744,0.002L57.34,41.876L39.852,41.92 C36.746,41.928,35.543,44.057,35.709,46.547L35.709,46.547z M59.908,41.899c0.068-0.102,5.194-0.532,5.137,3.662 C65.01,48.129,65.29,73.16,65.29,73.16s0.033,0.725-0.579-0.25c-0.61-0.979-4.638-8.297-4.638-8.297l-0.138-9.928 c0,0-0.264,0.959-0.684,3.332c-0.418,2.373-0.688,3.744-0.688,3.744l-12.322-0.014L59.908,41.899L59.908,41.899z M42.545,64.125 h15.896l5.54,9.967l-26.003,0.004c-0.279,0-0.333-0.486,0.008-1.145L42.545,64.125z', //墨水瓶
        'path://M32 18.451l-16-12.42-16 12.42v-5.064l16-12.42 16 12.42zM28 18v12h-8v-8h-8v8h-8v-12l12-9z', //房子
        'path://M12 20l4-2 14-14-2-2-14 14-2 4zM9.041 27.097c-0.989-2.085-2.052-3.149-4.137-4.137l3.097-8.525 4-2.435 12-12h-6l-12 12-6 20 20-6 12-12v-6l-12 12-2.435 4z', //铅笔
        'path://M0 32c4-12 14.469-32 32-32-8.219 6.594-12 22-18 22s-6 0-6 0l-6 10h-2z', //鹅毛笔
        'path://M31.818 9.122l-8.939-8.939c-0.292-0.292-0.676-0.226-0.855 0.146l-1.199 2.497 8.35 8.35 2.497-1.199c0.372-0.178 0.438-0.563 0.146-0.855zM19.231 4.231l-8.231 0.686c-0.547 0.068-1.002 0.184-1.159 0.899-0 0.001-0 0.001-0.001 0.002-2.232 10.721-9.84 21.183-9.84 21.183l1.793 1.793 8.5-8.5c-0.187-0.392-0.293-0.83-0.293-1.293 0-1.657 1.343-3 3-3s3 1.343 3 3-1.343 3-3 3c-0.463 0-0.902-0.105-1.293-0.293l-8.5 8.5 1.793 1.793c0 0 10.462-7.608 21.183-9.84 0.001-0 0.001-0 0.002-0.001 0.714-0.157 0.831-0.612 0.898-1.159l0.686-8.231-8.538-8.539z', //钢笔
        'path://M30.828 1.172c-1.562-1.562-4.095-1.562-5.657 0l-5.379 5.379-3.793-3.793-4.243 4.243 3.326 3.326-14.754 14.754c-0.252 0.252-0.358 0.592-0.322 0.921h-0.008v5c0 0.552 0.448 1 1 1h5c0 0 0.083 0 0.125 0 0.288 0 0.576-0.11 0.795-0.329l14.754-14.754 3.326 3.326 4.243-4.243-3.793-3.793 5.379-5.379c1.562-1.562 1.562-4.095 0-5.657zM5.409 30h-3.409v-3.409l14.674-14.674 3.409 3.409-14.674 14.674z', //吸管
        'path://M27.020 14.786c-2.055-5.732-6.41-10.88-11.020-14.786-4.61 3.907-8.965 9.054-11.020 14.786-1.271 3.545-1.396 7.393 0.393 10.794 2.058 3.911 6.207 6.42 10.626 6.42s8.569-2.509 10.626-6.42c1.79-3.401 1.664-7.249 0.393-10.794zM23.086 23.717c-1.369 2.602-4.15 4.283-7.086 4.283-1.723 0-3.391-0.579-4.753-1.583 0.414 0.054 0.832 0.083 1.254 0.083 3.67 0 7.146-2.1 8.856-5.351 1.402-2.665 1.281-5.433 0.746-7.636 0.455 0.88 0.841 1.756 1.151 2.623 0.706 1.971 1.251 4.886-0.168 7.581z', //水滴
        'path://M29.996 4c0.001 0.001 0.003 0.002 0.004 0.004v23.993c-0.001 0.001-0.002 0.003-0.004 0.004h-27.993c-0.001-0.001-0.003-0.002-0.004-0.004v-23.993c0.001-0.001 0.002-0.003 0.004-0.004h27.993zM30 2h-28c-1.1 0-2 0.9-2 2v24c0 1.1 0.9 2 2 2h28c1.1 0 2-0.9 2-2v-24c0-1.1-0.9-2-2-2v0zM26 9c0 1.657-1.343 3-3 3s-3-1.343-3-3 1.343-3 3-3 3 1.343 3 3zM28 26h-24v-4l7-12 8 10h2l7-6z', //图片
        'path://M9.5 19c0 3.59 2.91 6.5 6.5 6.5s6.5-2.91 6.5-6.5-2.91-6.5-6.5-6.5-6.5 2.91-6.5 6.5zM30 8h-7c-0.5-2-1-4-3-4h-8c-2 0-2.5 2-3 4h-7c-1.1 0-2 0.9-2 2v18c0 1.1 0.9 2 2 2h28c1.1 0 2-0.9 2-2v-18c0-1.1-0.9-2-2-2zM16 27.875c-4.902 0-8.875-3.973-8.875-8.875s3.973-8.875 8.875-8.875c4.902 0 8.875 3.973 8.875 8.875s-3.973 8.875-8.875 8.875zM30 14h-4v-2h4v2z', //相机
        'path://M9 18h-2v14h2c0.55 0 1-0.45 1-1v-12c0-0.55-0.45-1-1-1zM23 18c-0.55 0-1 0.45-1 1v12c0 0.55 0.45 1 1 1h2v-14h-2zM32 16c0-8.837-7.163-16-16-16s-16 7.163-16 16c0 1.919 0.338 3.759 0.958 5.464-0.609 1.038-0.958 2.246-0.958 3.536 0 3.526 2.608 6.443 6 6.929v-13.857c-0.997 0.143-1.927 0.495-2.742 1.012-0.168-0.835-0.258-1.699-0.258-2.584 0-7.18 5.82-13 13-13s13 5.82 13 13c0 0.885-0.088 1.749-0.257 2.584-0.816-0.517-1.745-0.87-2.743-1.013v13.858c3.392-0.485 6-3.402 6-6.929 0-1.29-0.349-2.498-0.958-3.536 0.62-1.705 0.958-3.545 0.958-5.465z', //耳机
        'path://M30 0h2v23c0 2.761-3.134 5-7 5s-7-2.239-7-5c0-2.761 3.134-5 7-5 1.959 0 3.729 0.575 5 1.501v-11.501l-16 3.556v15.444c0 2.761-3.134 5-7 5s-7-2.239-7-5c0-2.761 3.134-5 7-5 1.959 0 3.729 0.575 5 1.501v-19.501l18-4z', //音乐
        'path://M25.549 10.88c-6.049-4.496-8.133-8.094-9.549-10.88v0c-0 0-0-0-0-0v0c-1.415 2.785-3.5 6.384-9.549 10.88-10.314 7.665-0.606 18.365 7.93 12.476-0.556 3.654-2.454 6.318-4.381 7.465v1.179h12.001v-1.179c-1.928-1.147-3.825-3.811-4.382-7.465 8.535 5.889 18.244-4.811 7.93-12.476z', //桃形（扑克牌里的黑桃）
        'path://M24.588 12.274c-1.845 0-3.503 0.769-4.683 2.022-0.5 0.531-1.368 1.16-2.306 1.713 0.441-1.683 1.834-3.803 2.801-4.733 1.239-1.193 2-2.87 2-4.734 0-3.59-2.859-6.503-6.4-6.541-3.541 0.038-6.4 2.951-6.4 6.541 0 1.865 0.761 3.542 2 4.734 0.967 0.93 2.36 3.050 2.801 4.733-0.939-0.553-1.806-1.182-2.306-1.713-1.18-1.253-2.838-2.022-4.683-2.022-3.575 0-6.471 2.927-6.471 6.541s2.897 6.542 6.471 6.542c1.845 0 3.503-0.792 4.683-2.045 0.525-0.558 1.451-1.254 2.447-1.832-0.094 4.615-2.298 8.005-4.541 9.341v1.179h12v-1.179c-2.244-1.335-4.448-4.726-4.541-9.341 0.995 0.578 1.922 1.274 2.447 1.832 1.18 1.253 2.838 2.045 4.683 2.045 3.575 0 6.471-2.928 6.471-6.542s-2.897-6.541-6.471-6.541z', //梅花
        'path://M15 22c2.761 0 5-2.239 5-5v-12c0-2.761-2.239-5-5-5s-5 2.239-5 5v12c0 2.761 2.239 5 5 5zM22 14v3c0 3.866-3.134 7-7 7s-7-3.134-7-7v-3h-2v3c0 4.632 3.5 8.447 8 8.944v4.056h-4v2h10v-2h-4v-4.056c4.5-0.497 8-4.312 8-8.944v-3h-2z', //麦克风
        'path://M28 4v26h-21c-1.657 0-3-1.343-3-3s1.343-3 3-3h19v-24h-20c-2.2 0-4 1.8-4 4v24c0 2.2 1.8 4 4 4h24v-28h-2zM7.002 26v0c-0.001 0-0.001 0-0.002 0-0.552 0-1 0.448-1 1s0.448 1 1 1c0.001 0 0.001-0 0.002-0v0h18.997v-2h-18.997z', //书本
        'path://M26 30l6-16h-26l-6 16zM4 12l-4 18v-26h9l4 4h13v4z', //文件夹
        'path://M22 0c-5.523 0-10 4.477-10 10 0 0.626 0.058 1.238 0.168 1.832l-12.168 12.168v6c0 1.105 0.895 2 2 2h2v-2h4v-4h4v-4h4l2.595-2.595c1.063 0.385 2.209 0.595 3.405 0.595 5.523 0 10-4.477 10-10s-4.477-10-10-10zM24.996 10.004c-1.657 0-3-1.343-3-3s1.343-3 3-3 3 1.343 3 3-1.343 3-3 3z', //钥匙
        'path://M18.5 14h-0.5v-6c0-3.308-2.692-6-6-6h-4c-3.308 0-6 2.692-6 6v6h-0.5c-0.825 0-1.5 0.675-1.5 1.5v15c0 0.825 0.675 1.5 1.5 1.5h17c0.825 0 1.5-0.675 1.5-1.5v-15c0-0.825-0.675-1.5-1.5-1.5zM6 8c0-1.103 0.897-2 2-2h4c1.103 0 2 0.897 2 2v6h-8v-6z', //锁-关闭状态
        'path://M24 2c3.308 0 6 2.692 6 6v6h-4v-6c0-1.103-0.897-2-2-2h-4c-1.103 0-2 0.897-2 2v6h0.5c0.825 0 1.5 0.675 1.5 1.5v15c0 0.825-0.675 1.5-1.5 1.5h-17c-0.825 0-1.5-0.675-1.5-1.5v-15c0-0.825 0.675-1.5 1.5-1.5h12.5v-6c0-3.308 2.692-6 6-6h4z', //锁-开启状态
        'path://M24.11 10c0.566-0.402 1.11-0.851 1.608-1.348 1.044-1.044 1.742-2.328 1.966-3.616 0.246-1.412-0.115-2.723-0.988-3.597-0.697-0.697-1.641-1.065-2.73-1.065-1.551 0-3.185 0.744-4.483 2.043-2.077 2.077-3.288 4.945-3.94 6.991-0.482-2.056-1.444-4.833-3.313-6.702-1.003-1.003-2.285-1.518-3.495-1.518-0.989 0-1.931 0.344-2.633 1.046-1.562 1.562-1.351 4.306 0.471 6.128 0.65 0.65 1.409 1.189 2.21 1.638h-6.782v8h2v14h24v-14h2v-8h-5.89zM21.073 4.007c0.866-0.866 1.948-1.384 2.892-1.384 0.334 0 0.803 0.070 1.139 0.406 0.813 0.813 0.357 2.697-0.977 4.031-1.373 1.373-3.221 2.318-4.826 2.939h-1.584c0.58-1.798 1.627-4.264 3.356-5.993zM7.31 5.028c-0.022-0.285-0.002-0.82 0.381-1.203 0.32-0.32 0.743-0.387 1.042-0.387v0c0.664 0 1.358 0.313 1.904 0.859 1.059 1.058 1.93 2.743 2.521 4.871 0.016 0.057 0.031 0.115 0.047 0.171-0.057-0.015-0.114-0.031-0.171-0.047-2.128-0.591-3.813-1.462-4.871-2.521-0.495-0.495-0.805-1.13-0.853-1.743zM14 30h-8v-13h8v13zM14 16h-10v-4h10v4zM26 30h-8v-13h8v13zM28 16h-10v-4h10v4z', //礼物
        'path://M30 10h-6v-3c0-2.761-5.373-5-12-5s-12 2.239-12 5v20c0 2.761 5.373 5 12 5s12-2.239 12-5v-3h6c1.105 0 2-0.895 2-2v-10c0-1.105-0.895-2-2-2zM5.502 8.075c-1.156-0.381-1.857-0.789-2.232-1.075 0.375-0.286 1.075-0.694 2.232-1.075 1.811-0.597 4.118-0.925 6.498-0.925s4.688 0.329 6.498 0.925c1.156 0.381 1.857 0.789 2.232 1.075-0.375 0.286-1.076 0.694-2.232 1.075-1.811 0.597-4.118 0.925-6.498 0.925s-4.688-0.329-6.498-0.925zM28 20h-4v-6h4v6z', //杯子
        'path://M16 0c-8.837 0-16 7.163-16 16s7.163 16 16 16c8.837 0 16-7.163 16-16s-7.163-16-16-16zM22 7.375c1.999 0 3.625 1.626 3.625 3.625 0 0.199-0.017 0.402-0.051 0.604-0.051 0.301-0.311 0.521-0.616 0.521s-0.566-0.22-0.616-0.522c-0.192-1.146-1.177-1.666-2.341-1.666s-2.149 0.52-2.341 1.666c-0.050 0.301-0.311 0.522-0.616 0.522-0 0 0 0-0 0-0.305 0-0.566-0.22-0.616-0.521-0.034-0.201-0.051-0.404-0.051-0.604 0-1.999 1.626-3.625 3.625-3.625zM10 7.375c1.999 0 3.625 1.626 3.625 3.625 0 0.199-0.017 0.402-0.051 0.604-0.051 0.301-0.311 0.521-0.616 0.521s-0.566-0.22-0.616-0.522c-0.193-1.146-1.177-1.666-2.341-1.666s-2.149 0.52-2.341 1.666c-0.051 0.301-0.311 0.522-0.616 0.522 0 0 0 0 0 0-0.305 0-0.566-0.22-0.616-0.521-0.034-0.201-0.051-0.404-0.051-0.604 0-1.999 1.626-3.625 3.625-3.625zM6 18h6v7.745c-3.44-0.894-6-4.035-6-7.745zM14 26v-8h4v8h-4zM20 25.745v-7.745h6c0 3.71-2.559 6.851-6 7.745z', //露齿笑
        'path://M32 13.414c0-6.279-1.837-11.373-4.109-11.413 0.009-0 0.018-0.001 0.027-0.001h-2.592c0 0-6.088 4.573-14.851 6.367-0.268 1.415-0.438 3.102-0.438 5.047s0.171 3.631 0.438 5.047c8.763 1.794 14.851 6.367 14.851 6.367h2.592c-0.009 0-0.018-0.001-0.027-0.001 2.272-0.040 4.109-5.134 4.109-11.413zM27.026 23.102c-0.293 0-0.61-0.304-0.773-0.486-0.395-0.439-0.775-1.124-1.1-1.979-0.727-1.913-1.127-4.478-1.127-7.223s0.4-5.309 1.127-7.223c0.325-0.855 0.705-1.54 1.1-1.979 0.163-0.182 0.48-0.486 0.773-0.486s0.61 0.304 0.773 0.486c0.395 0.439 0.775 1.124 1.1 1.979 0.727 1.913 1.127 4.479 1.127 7.223s-0.4 5.309-1.127 7.223c-0.325 0.855-0.705 1.54-1.1 1.979-0.163 0.181-0.48 0.486-0.773 0.486zM7.869 13.414c0-1.623 0.119-3.201 0.345-4.659-1.48 0.205-2.779 0.323-4.386 0.323-2.096 0-2.096 0-2.096 0l-1.733 2.959v2.755l1.733 2.959c0 0 0 0 2.096 0 1.606 0 2.905 0.118 4.386 0.323-0.226-1.458-0.345-3.036-0.345-4.659zM11.505 20.068l-4-0.766 2.558 10.048c0.132 0.52 0.648 0.782 1.146 0.583l3.705-1.483c0.498-0.199 0.698-0.749 0.444-1.221l-3.853-7.161zM27.026 17.148c-0.113 0-0.235-0.117-0.298-0.187-0.152-0.169-0.299-0.433-0.424-0.763-0.28-0.738-0.434-1.726-0.434-2.784s0.154-2.046 0.434-2.784c0.125-0.33 0.272-0.593 0.424-0.763 0.063-0.070 0.185-0.187 0.298-0.187s0.235 0.117 0.298 0.187c0.152 0.169 0.299 0.433 0.424 0.763 0.28 0.737 0.434 1.726 0.434 2.784s-0.154 2.046-0.434 2.784c-0.125 0.33-0.272 0.593-0.424 0.763-0.063 0.070-0.185 0.187-0.298 0.187z', //喇叭
        'path://M20 18c3.308 0 6.308 1.346 8.481 3.519l-2.827 2.827c-1.449-1.449-3.449-2.346-5.654-2.346s-4.206 0.897-5.654 2.346l-2.827-2.827c2.173-2.173 5.173-3.519 8.481-3.519zM5.858 15.858c3.777-3.777 8.8-5.858 14.142-5.858s10.365 2.080 14.142 5.858l-2.828 2.828c-3.022-3.022-7.040-4.686-11.314-4.686s-8.292 1.664-11.314 4.686l-2.828-2.828zM30.899 4.201c3.334 1.41 6.329 3.429 8.899 6v0l-2.828 2.828c-4.533-4.533-10.56-7.029-16.971-7.029s-12.438 2.496-16.971 7.029l-2.828-2.828c2.571-2.571 5.565-4.589 8.899-6 3.453-1.461 7.12-2.201 10.899-2.201s7.446 0.741 10.899 2.201zM18 28c0-1.105 0.895-2 2-2s2 0.895 2 2c0 1.105-0.895 2-2 2s-2-0.895-2-2z', //信号强度
        'path://M12 29c0 1.657-1.343 3-3 3s-3-1.343-3-3c0-1.657 1.343-3 3-3s3 1.343 3 3zM32 29c0 1.657-1.343 3-3 3s-3-1.343-3-3c0-1.657 1.343-3 3-3s3 1.343 3 3zM32 16v-12h-24c0-1.105-0.895-2-2-2h-6v2h4l1.502 12.877c-0.915 0.733-1.502 1.859-1.502 3.123 0 2.209 1.791 4 4 4h24v-2h-24c-1.105 0-2-0.895-2-2 0-0.007 0-0.014 0-0.020l26-3.98z', //购物车
        'path://M22 20c-2 2-2 4-4 4s-4-2-6-4-4-4-4-6 2-2 4-4-4-8-6-8-6 6-6 6c0 4 4.109 12.109 8 16s12 8 16 8c0 0 6-4 6-6s-6-8-8-6z', //电话
        'path://M31.793 18c0.25 1.734 0.413 4.106-0.364 5.014-1.286 1.501-9.428 1.501-9.428-1.501 0-1.512 1.339-2.504 0.053-4.006-1.265-1.477-3.532-1.501-6.054-1.501s-4.789 0.024-6.054 1.501c-1.286 1.501 0.054 2.493 0.054 4.006 0 3.003-8.143 3.003-9.429 1.501-0.777-0.908-0.615-3.28-0.364-5.014 0.193-1.157 0.679-2.406 2.236-4 0-0 0-0 0-0 2.336-2.179 5.87-3.961 13.432-3.999v-0.001c0.042 0 0.083 0 0.125 0s0.083-0 0.125-0v0.001c7.562 0.038 11.096 1.82 13.432 3.999 0 0 0 0 0 0 1.557 1.594 2.043 2.842 2.236 4z', //电话
        'path://M29 4h-26c-1.65 0-3 1.35-3 3v20c0 1.65 1.35 3 3 3h26c1.65 0 3-1.35 3-3v-20c0-1.65-1.35-3-3-3zM12.461 17.199l-8.461 6.59v-15.676l8.461 9.086zM5.512 8h20.976l-10.488 7.875-10.488-7.875zM12.79 17.553l3.21 3.447 3.21-3.447 6.58 8.447h-19.579l6.58-8.447zM19.539 17.199l8.461-9.086v15.676l-8.461-6.59z', //信件，邮件
        'path://M0 2v20h32v-20h-32zM30 20h-28v-16h28v16zM21 24h-10l-1 4-2 2h16l-2-2z', //电脑显示器
        'path://M23 0h-14c-1.65 0-3 1.35-3 3v26c0 1.65 1.35 3 3 3h14c1.65 0 3-1.35 3-3v-26c0-1.65-1.35-3-3-3zM12 1.5h8v1h-8v-1zM16 30c-1.105 0-2-0.895-2-2s0.895-2 2-2 2 0.895 2 2-0.895 2-2 2zM24 24h-16v-20h16v20z', //智能手机
        'path://M25 0h-20c-1.65 0-3 1.35-3 3v26c0 1.65 1.35 3 3 3h20c1.65 0 3-1.35 3-3v-26c0-1.65-1.35-3-3-3zM15 31c-0.552 0-1-0.448-1-1s0.448-1 1-1 1 0.448 1 1-0.448 1-1 1zM24 28h-18v-24h18v24z', //平板电脑--pad
        'path://M30.662 9.003c-2.775-0.399-5.731-0.688-8.815-0.851l5.153-5.153-2-2-7.017 7.017c-0.656-0.011-1.317-0.017-1.983-0.017v0l-8-8-2 2 6.069 6.069c-3.779 0.133-7.386 0.454-10.731 0.935-0.86 3.366-1.338 7.086-1.338 10.997s0.477 7.63 1.338 10.997c4.489 0.645 9.448 1.003 14.662 1.003s10.173-0.358 14.662-1.003c0.86-3.366 1.338-7.086 1.338-10.997s-0.477-7.63-1.338-10.997zM26.997 27.331c-3.367 0.43-7.086 0.669-10.997 0.669s-7.63-0.239-10.997-0.669c-0.645-2.244-1.003-4.724-1.003-7.331s0.358-5.087 1.003-7.331c3.366-0.43 7.086-0.669 10.997-0.669s7.63 0.239 10.996 0.669c0.645 2.244 1.004 4.724 1.004 7.331s-0.358 5.087-1.003 7.331z', //电视机
        'path://M24 24.082v-1.649c2.203-1.241 4-4.337 4-7.432 0-4.971 0-9-6-9s-6 4.029-6 9c0 3.096 1.797 6.191 4 7.432v1.649c-6.784 0.555-12 3.888-12 7.918h28c0-4.030-5.216-7.364-12-7.918zM10.225 24.854c1.728-1.13 3.877-1.989 6.243-2.513-0.47-0.556-0.897-1.176-1.265-1.844-0.95-1.726-1.453-3.627-1.453-5.497 0-2.689 0-5.228 0.956-7.305 0.928-2.016 2.598-3.265 4.976-3.734-0.529-2.39-1.936-3.961-5.682-3.961-6 0-6 4.029-6 9 0 3.096 1.797 6.191 4 7.432v1.649c-6.784 0.555-12 3.888-12 7.918h8.719c0.454-0.403 0.956-0.787 1.506-1.146z', //用户
        'path://M12 23c0-4.726 2.996-8.765 7.189-10.319 0.509-1.142 0.811-2.411 0.811-3.681 0-4.971 0-9-6-9s-6 4.029-6 9c0 3.096 1.797 6.191 4 7.432v1.649c-6.784 0.555-12 3.888-12 7.918h12.416c-0.271-0.954-0.416-1.96-0.416-3zM23 14c-4.971 0-9 4.029-9 9s4.029 9 9 9c4.971 0 9-4.029 9-9s-4.029-9-9-9zM28 24h-4v4h-2v-4h-4v-2h4v-4h2v4h4v2z', //添加用户
        'path://M12 23c0-4.726 2.996-8.765 7.189-10.319 0.509-1.142 0.811-2.411 0.811-3.681 0-4.971 0-9-6-9s-6 4.029-6 9c0 3.096 1.797 6.191 4 7.432v1.649c-6.784 0.555-12 3.888-12 7.918h12.416c-0.271-0.954-0.416-1.96-0.416-3zM23 14c-4.971 0-9 4.029-9 9s4.029 9 9 9c4.971 0 9-4.029 9-9s-4.029-9-9-9zM28 24h-10v-2h10v2z', //删除用户
        'path://M31.342 25.559l-14.392-12.336c0.67-1.259 1.051-2.696 1.051-4.222 0-4.971-4.029-9-9-9-0.909 0-1.787 0.135-2.614 0.386l5.2 5.2c0.778 0.778 0.778 2.051 0 2.828l-3.172 3.172c-0.778 0.778-2.051 0.778-2.828 0l-5.2-5.2c-0.251 0.827-0.386 1.705-0.386 2.614 0 4.971 4.029 9 9 9 1.526 0 2.963-0.38 4.222-1.051l12.336 14.392c0.716 0.835 1.938 0.882 2.716 0.104l3.172-3.172c0.778-0.778 0.731-2-0.104-2.716z', //扳手
        'path://M31.568 28.617l-17.145-15.608 0.798-0.8c0.653-0.655 1.006-1.501 1.060-2.363 0.031-0.014 0.063-0.028 0.092-0.045l3.218-2.013c0.435-0.512 0.404-1.321-0.071-1.797l-5.598-5.613c-0.475-0.476-1.281-0.508-1.792-0.071l-2.007 3.227c-0.016 0.030-0.031 0.061-0.045 0.093-0.859 0.054-1.703 0.408-2.356 1.063l-3.045 3.053c-0.653 0.655-1.006 1.501-1.060 2.363-0.031 0.014-0.063 0.029-0.093 0.045l-3.218 2.013c-0.436 0.512-0.404 1.321 0.071 1.797l5.598 5.613c0.475 0.476 1.281 0.508 1.792 0.071l2.007-3.227c0.017-0.030 0.031-0.061 0.045-0.093 0.859-0.054 1.703-0.408 2.356-1.063l0.884-0.887 15.566 17.191c0.451 0.498 1.147 0.579 1.546 0.178l1.574-1.578c0.399-0.4 0.319-1.098-0.178-1.55z', //锤子
        'path://M10.031 32c-2.133-4.438-0.997-6.981 0.642-9.376 1.795-2.624 2.258-5.221 2.258-5.221s1.411 1.834 0.847 4.703c2.493-2.775 2.963-7.196 2.587-8.889 5.635 3.938 8.043 12.464 4.798 18.783 17.262-9.767 4.294-24.38 2.036-26.027 0.753 1.646 0.895 4.433-0.625 5.785-2.573-9.759-8.937-11.759-8.937-11.759 0.753 5.033-2.728 10.536-6.084 14.648-0.118-2.007-0.243-3.392-1.298-5.312-0.237 3.646-3.023 6.617-3.777 10.27-1.022 4.946 0.765 8.568 7.555 12.394z', //火焰
        'path://M32 18l-4-8h-6v-4c0-1.1-0.9-2-2-2h-18c-1.1 0-2 0.9-2 2v16l2 2h2.536c-0.341 0.588-0.536 1.271-0.536 2 0 2.209 1.791 4 4 4s4-1.791 4-4c0-0.729-0.196-1.412-0.536-2h11.073c-0.341 0.588-0.537 1.271-0.537 2 0 2.209 1.791 4 4 4s4-1.791 4-4c0-0.729-0.196-1.412-0.537-2h2.537v-6zM22 18v-6h4.146l3 6h-7.146z', //货车
        'path://M18 3c0 1.657-1.343 3-3 3s-3-1.343-3-3c0-1.657 1.343-3 3-3s3 1.343 3 3zM18 8h-6c-1.105 0-2 0.895-2 2v10h2v12h2.5v-12h1v12h2.5v-12h2v-10c0-1.105-0.895-2-2-2z', //man
        'path://M18 3c0 1.657-1.343 3-3 3s-3-1.343-3-3c0-1.657 1.343-3 3-3s3 1.343 3 3zM22.469 16l1.531-1.109-4.165-6.441c-0.185-0.281-0.499-0.45-0.835-0.45h-8c-0.336 0-0.65 0.169-0.835 0.45l-4.165 6.441 1.531 1.109 3.458-4.487 1.202 2.804-4.191 7.683h3.833l0.667 10h2v-10h1v10h2l0.667-10h3.833l-4.191-7.683 1.202-2.804 3.458 4.487z', //women
        'path://M8 3c0 1.657-1.343 3-3 3s-3-1.343-3-3c0-1.657 1.343-3 3-3s3 1.343 3 3zM26 3c0 1.657-1.343 3-3 3s-3-1.343-3-3c0-1.657 1.343-3 3-3s3 1.343 3 3zM8 8h-6c-1.105 0-2 0.895-2 2v10h2v12h2.5v-12h1v12h2.5v-12h2v-10c0-1.105-0.895-2-2-2zM30.469 16l1.531-1.109-4.165-6.441c-0.185-0.281-0.499-0.45-0.835-0.45h-8c-0.336 0-0.65 0.169-0.835 0.45l-4.165 6.441 1.531 1.109 3.458-4.487 1.202 2.804-4.191 7.683h3.833l0.667 10h2v-10h1v10h2l0.667-10h3.833l-4.191-7.683 1.202-2.804 3.458 4.487z', //man——women
        'path://M16 32c8.837 0 16-7.163 16-16s-7.163-16-16-16-16 7.163-16 16 7.163 16 16 16zM16 3c7.18 0 13 5.82 13 13s-5.82 13-13 13-13-5.82-13-13 5.82-13 13-13zM25 8c0.55 0 1 0.45 1 1v3c0 1.1-0.9 2-2 2h-4c-1.1 0-2-0.9-2-2h-4c0 1.1-0.9 2-2 2h-4c-1.1 0-2-0.9-2-2v-3c0-0.55 0.45-1 1-1h6c0.55 0 1 0.45 1 1v1h4v-1c0-0.55 0.45-1 1-1h6zM16 24c2.913 0 5.462-1.557 6.861-3.884l1.715 1.029c-1.749 2.908-4.935 4.855-8.576 4.855-1.514 0-2.95-0.337-4.236-0.94l1.036-1.727c0.98 0.429 2.061 0.668 3.199 0.668z', //戴墨镜
        'path://M16 2.899l13.409 26.726h-26.819l13.409-26.726zM16 0c-0.69 0-1.379 0.465-1.903 1.395l-13.659 27.222c-1.046 1.86-0.156 3.383 1.978 3.383h27.166c2.134 0 3.025-1.522 1.978-3.383h0l-13.659-27.222c-0.523-0.93-1.213-1.395-1.903-1.395v0zM18 26c0 1.105-0.895 2-2 2s-2-0.895-2-2c0-1.105 0.895-2 2-2s2 0.895 2 2zM16 22c-1.105 0-2-0.895-2-2v-6c0-1.105 0.895-2 2-2s2 0.895 2 2v6c0 1.105-0.895 2-2 2z', //警告
        'path://M27.314 4.686c-3.022-3.022-7.040-4.686-11.314-4.686s-8.292 1.664-11.314 4.686c-3.022 3.022-4.686 7.040-4.686 11.314s1.664 8.292 4.686 11.314c3.022 3.022 7.040 4.686 11.314 4.686s8.292-1.664 11.314-4.686c3.022-3.022 4.686-7.040 4.686-11.314s-1.664-8.292-4.686-11.314zM28 16c0 2.588-0.824 4.987-2.222 6.949l-16.727-16.727c1.962-1.399 4.361-2.222 6.949-2.222 6.617 0 12 5.383 12 12zM4 16c0-2.588 0.824-4.987 2.222-6.949l16.727 16.727c-1.962 1.399-4.361 2.222-6.949 2.222-6.617 0-12-5.383-12-12z', //禁止通行
        'path://M31.708 25.708c-0-0-0-0-0-0l-9.708-9.708 9.708-9.708c0-0 0-0 0-0 0.105-0.105 0.18-0.227 0.229-0.357 0.133-0.356 0.057-0.771-0.229-1.057l-4.586-4.586c-0.286-0.286-0.702-0.361-1.057-0.229-0.13 0.048-0.252 0.124-0.357 0.228 0 0-0 0-0 0l-9.708 9.708-9.708-9.708c-0-0-0-0-0-0-0.105-0.104-0.227-0.18-0.357-0.228-0.356-0.133-0.771-0.057-1.057 0.229l-4.586 4.586c-0.286 0.286-0.361 0.702-0.229 1.057 0.049 0.13 0.124 0.252 0.229 0.357 0 0 0 0 0 0l9.708 9.708-9.708 9.708c-0 0-0 0-0 0-0.104 0.105-0.18 0.227-0.229 0.357-0.133 0.355-0.057 0.771 0.229 1.057l4.586 4.586c0.286 0.286 0.702 0.361 1.057 0.229 0.13-0.049 0.252-0.124 0.357-0.229 0-0 0-0 0-0l9.708-9.708 9.708 9.708c0 0 0 0 0 0 0.105 0.105 0.227 0.18 0.357 0.229 0.356 0.133 0.771 0.057 1.057-0.229l4.586-4.586c0.286-0.286 0.362-0.702 0.229-1.057-0.049-0.13-0.124-0.252-0.229-0.357z', //wrong
        'path://M27 4l-15 15-7-7-5 5 12 12 20-20z', //right
        'path://M28 12c-1.1 0-2 0.9-2 2v8c0 1.1 0.9 2 2 2s2-0.9 2-2v-8c0-1.1-0.9-2-2-2zM4 12c-1.1 0-2 0.9-2 2v8c0 1.1 0.9 2 2 2s2-0.9 2-2v-8c0-1.1-0.9-2-2-2zM7 23c0 1.657 1.343 3 3 3v0 4c0 1.1 0.9 2 2 2s2-0.9 2-2v-4h4v4c0 1.1 0.9 2 2 2s2-0.9 2-2v-4c1.657 0 3-1.343 3-3v-11h-18v11zM24.944 10c-0.304-2.746-1.844-5.119-4.051-6.551l1.001-2.001c0.247-0.494 0.047-1.095-0.447-1.342s-1.095-0.047-1.342 0.447l-1.004 2.009-0.261-0.104c-0.893-0.297-1.848-0.458-2.84-0.458s-1.947 0.161-2.84 0.458l-0.261 0.104-1.004-2.009c-0.247-0.494-0.848-0.694-1.342-0.447s-0.694 0.848-0.447 1.342l1.001 2.001c-2.207 1.433-3.747 3.805-4.051 6.551v1h17.944v-1h-0.056zM13 8c-0.552 0-1-0.448-1-1s0.447-0.999 0.998-1c0.001 0 0.002 0 0.003 0s0.001-0 0.002-0c0.551 0.001 0.998 0.448 0.998 1s-0.448 1-1 1zM19 8c-0.552 0-1-0.448-1-1s0.446-0.999 0.998-1c0 0 0.001 0 0.002 0s0.002-0 0.003-0c0.551 0.001 0.998 0.448 0.998 1s-0.448 1-1 1z', //安卓
        'path://M16 0c-5.523 0-10 4.477-10 10 0 10 10 22 10 22s10-12 10-22c0-5.523-4.477-10-10-10zM16 16c-3.314 0-6-2.686-6-6s2.686-6 6-6 6 2.686 6 6-2.686 6-6 6z', //location
        'path://M16 2c-4.418 0-8.418 1.791-11.313 4.687l-4.686-4.687v12h12l-4.485-4.485c2.172-2.172 5.172-3.515 8.485-3.515 6.627 0 12 5.373 12 12 0 3.584-1.572 6.801-4.063 9l2.646 3c3.322-2.932 5.417-7.221 5.417-12 0-8.837-7.163-16-16-16z', //undo
        'path://M0 18c0 4.779 2.095 9.068 5.417 12l2.646-3c-2.491-2.199-4.063-5.416-4.063-9 0-6.627 5.373-12 12-12 3.314 0 6.314 1.343 8.485 3.515l-4.485 4.485h12v-12l-4.687 4.687c-2.895-2.896-6.895-4.687-11.313-4.687-8.837 0-16 7.163-16 16z', //redo
        'path://M23.808 32c3.554-6.439 4.153-16.26-9.808-15.932v7.932l-12-12 12-12v7.762c16.718-0.436 18.58 14.757 9.808 24.238z', //undo
        'path://M18 7.762v-7.762l12 12-12 12v-7.932c-13.961-0.328-13.362 9.493-9.808 15.932-8.772-9.482-6.909-24.674 9.808-24.238z', //redo
        'path://M8.192 0c-3.554 6.439-4.153 16.259 9.808 15.932v-7.932l12 12-12 12v-7.762c-16.718 0.436-18.58-14.757-9.808-24.238z', //forward
        'path://M14 24.238v7.762l-12-12 12-12v7.932c13.961 0.327 13.362-9.493 9.808-15.932 8.772 9.482 6.909 24.674-9.808 24.238z', //replay
        'path://M16 2c8.837 0 16 5.82 16 13s-7.163 13-16 13c-0.849 0-1.682-0.054-2.495-0.158-3.437 3.437-7.539 4.053-11.505 4.144v-0.841c2.142-1.049 4-2.961 4-5.145 0-0.305-0.024-0.604-0.068-0.897-3.619-2.383-5.932-6.024-5.932-10.103 0-7.18 7.163-13 16-13z', //气泡
        'path://M22.781 16c4.305-2.729 7.219-7.975 7.219-14 0-0.677-0.037-1.345-0.109-2h-27.783c-0.072 0.655-0.109 1.323-0.109 2 0 6.025 2.914 11.271 7.219 14-4.305 2.729-7.219 7.975-7.219 14 0 0.677 0.037 1.345 0.109 2h27.783c0.072-0.655 0.109-1.323 0.109-2 0-6.025-2.914-11.271-7.219-14zM5 30c0-5.841 2.505-10.794 7-12.428v-3.143c-4.495-1.634-7-6.587-7-12.428v0h22c0 5.841-2.505 10.794-7 12.428v3.143c4.495 1.634 7 6.587 7 12.428h-22zM19.363 20.925c-2.239-1.27-2.363-2.918-2.363-3.918v-2.007c0-1 0.119-2.654 2.367-3.927 1.203-0.699 2.244-1.761 3.033-3.073h-12.799c0.79 1.313 1.832 2.376 3.036 3.075 2.239 1.27 2.363 2.918 2.363 3.918v2.007c0 1-0.119 2.654-2.367 3.927-2.269 1.318-3.961 3.928-4.472 7.073h15.677c-0.511-3.147-2.204-5.758-4.475-7.075z', //沙漏
        'path://M16 9.472c-1.030 0-1.865-0.835-1.865-1.865v-5.596c0-1.030 0.835-1.865 1.865-1.865s1.865 0.835 1.865 1.865v5.596c0 1.030-0.835 1.865-1.865 1.865zM16 31.155c-0.644 0-1.166-0.522-1.166-1.166v-5.596c0-0.644 0.522-1.166 1.166-1.166s1.166 0.522 1.166 1.166v5.596c0 0.644-0.522 1.166-1.166 1.166zM11.805 10.48c-0.604 0-1.192-0.314-1.516-0.875l-2.798-4.846c-0.483-0.836-0.196-1.906 0.64-2.389s1.906-0.196 2.389 0.64l2.798 4.846c0.483 0.836 0.196 1.906-0.64 2.389-0.275 0.159-0.576 0.235-0.873 0.235zM22.995 29.164c-0.363 0-0.715-0.188-0.91-0.525l-2.798-4.846c-0.29-0.502-0.118-1.143 0.384-1.433s1.143-0.118 1.433 0.384l2.798 4.846c0.29 0.502 0.118 1.143-0.384 1.433-0.165 0.095-0.346 0.141-0.524 0.141zM8.729 13.436c-0.277 0-0.557-0.070-0.814-0.219l-4.846-2.798c-0.781-0.451-1.048-1.449-0.597-2.229s1.449-1.048 2.229-0.597l4.846 2.798c0.781 0.451 1.048 1.449 0.597 2.229-0.302 0.524-0.851 0.816-1.415 0.816zM28.114 23.927c-0.158 0-0.319-0.040-0.465-0.125l-4.846-2.798c-0.446-0.258-0.599-0.828-0.341-1.274s0.828-0.599 1.274-0.341l4.846 2.798c0.446 0.258 0.599 0.828 0.341 1.274-0.173 0.299-0.486 0.466-0.809 0.466zM7.607 17.515h-5.596c-0.837 0-1.516-0.678-1.516-1.515s0.678-1.515 1.516-1.515h5.596c0.837 0 1.516 0.678 1.516 1.515s-0.678 1.515-1.516 1.515zM29.989 16.933c-0 0 0 0 0 0h-5.596c-0.515-0-0.933-0.418-0.933-0.933s0.418-0.933 0.933-0.933c0 0 0 0 0 0h5.596c0.515 0 0.933 0.418 0.933 0.933s-0.418 0.933-0.933 0.933zM3.886 24.394c-0.483 0-0.954-0.251-1.213-0.7-0.386-0.669-0.157-1.525 0.512-1.911l4.846-2.798c0.669-0.387 1.525-0.157 1.911 0.512s0.157 1.525-0.512 1.911l-4.846 2.798c-0.22 0.127-0.461 0.188-0.698 0.188zM23.27 12.736c-0.322 0-0.636-0.167-0.809-0.466-0.258-0.446-0.105-1.016 0.341-1.274l4.846-2.798c0.446-0.257 1.016-0.105 1.274 0.341s0.105 1.016-0.341 1.274l-4.846 2.798c-0.147 0.085-0.307 0.125-0.465 0.125zM9.004 29.397c-0.218 0-0.438-0.055-0.64-0.172-0.613-0.354-0.823-1.138-0.469-1.752l2.798-4.846c0.354-0.613 1.138-0.823 1.752-0.469s0.823 1.138 0.469 1.752l-2.798 4.846c-0.237 0.411-0.668 0.641-1.112 0.641zM20.196 9.664c-0.158 0-0.319-0.040-0.465-0.125-0.446-0.258-0.599-0.828-0.341-1.274l2.798-4.846c0.258-0.446 0.828-0.599 1.274-0.341s0.599 0.828 0.341 1.274l-2.798 4.846c-0.173 0.299-0.486 0.466-0.809 0.466z', //loading
        'path://M32 12h-12l4.485-4.485c-2.267-2.266-5.28-3.515-8.485-3.515s-6.219 1.248-8.485 3.515c-2.266 2.267-3.515 5.28-3.515 8.485s1.248 6.219 3.515 8.485c2.267 2.266 5.28 3.515 8.485 3.515s6.219-1.248 8.485-3.515c0.189-0.189 0.371-0.384 0.546-0.583l3.010 2.634c-2.933 3.349-7.239 5.464-12.041 5.464-8.837 0-16-7.163-16-16s7.163-16 16-16c4.418 0 8.418 1.791 11.313 4.687l4.687-4.687v12z', //
        'path://M31.008 27.231l-7.58-6.447c-0.784-0.705-1.622-1.029-2.299-0.998 1.789-2.096 2.87-4.815 2.87-7.787 0-6.627-5.373-12-12-12s-12 5.373-12 12 5.373 12 12 12c2.972 0 5.691-1.081 7.787-2.87-0.031 0.677 0.293 1.515 0.998 2.299l6.447 7.58c1.104 1.226 2.907 1.33 4.007 0.23s0.997-2.903-0.23-4.007zM12 20c-4.418 0-8-3.582-8-8s3.582-8 8-8 8 3.582 8 8-3.582 8-8 8z', //search
        'path://M31.008 27.231l-7.58-6.447c-0.784-0.705-1.622-1.029-2.299-0.998 1.789-2.096 2.87-4.815 2.87-7.787 0-6.627-5.373-12-12-12s-12 5.373-12 12 5.373 12 12 12c2.972 0 5.691-1.081 7.787-2.87-0.031 0.677 0.293 1.515 0.998 2.299l6.447 7.58c1.104 1.226 2.907 1.33 4.007 0.23s0.997-2.903-0.23-4.007zM12 20c-4.418 0-8-3.582-8-8s3.582-8 8-8 8 3.582 8 8-3.582 8-8 8zM14 6h-4v4h-4v4h4v4h4v-4h4v-4h-4z', //放大
        'path://M31.008 27.231l-7.58-6.447c-0.784-0.705-1.622-1.029-2.299-0.998 1.789-2.096 2.87-4.815 2.87-7.787 0-6.627-5.373-12-12-12s-12 5.373-12 12 5.373 12 12 12c2.972 0 5.691-1.081 7.787-2.87-0.031 0.677 0.293 1.515 0.998 2.299l6.447 7.58c1.104 1.226 2.907 1.33 4.007 0.23s0.997-2.903-0.23-4.007zM12 20c-4.418 0-8-3.582-8-8s3.582-8 8-8 8 3.582 8 8-3.582 8-8 8zM6 10h12v4h-12z', //缩小
        'path://M32 0h-13l5 5-6 6 3 3 6-6 5 5z M32 32v-13l-5 5-6-6-3 3 6 6-5 5z M0 32h13l-5-5 6-6-3-3-6 6-5-5z M0 0v13l5-5 6 6 3-3-6-6 5-5z', //全屏， 屏幕放大
        'path://M32 0v13l-5-5-6 6-3-3 6-6-5-5zM14 21l-6 6 5 5h-13v-13l5 5 6-6z', //屏幕放大
        'path://M14 18v13l-5-5-6 6-3-3 6-6-5-5zM32 3l-6 6 5 5h-13v-13l5 5 6-6z', //屏幕缩小
        'path://M29.181 19.070c-1.679-2.908-0.669-6.634 2.255-8.328l-3.145-5.447c-0.898 0.527-1.943 0.829-3.058 0.829-3.361 0-6.085-2.742-6.085-6.125h-6.289c0.008 1.044-0.252 2.103-0.811 3.070-1.679 2.908-5.411 3.897-8.339 2.211l-3.144 5.447c0.905 0.515 1.689 1.268 2.246 2.234 1.676 2.903 0.672 6.623-2.241 8.319l3.145 5.447c0.895-0.522 1.935-0.82 3.044-0.82 3.35 0 6.067 2.725 6.084 6.092h6.289c-0.003-1.034 0.259-2.080 0.811-3.038 1.676-2.903 5.399-3.894 8.325-2.219l3.145-5.447c-0.899-0.515-1.678-1.266-2.232-2.226zM16 22.479c-3.578 0-6.479-2.901-6.479-6.479s2.901-6.479 6.479-6.479c3.578 0 6.479 2.901 6.479 6.479s-2.901 6.479-6.479 6.479z', //设置
        'path://M28 8h-6v-4c0-1.1-0.9-2-2-2h-8c-1.1 0-2 0.9-2 2v4h-6c-2.2 0-4 1.8-4 4v16c0 2.2 1.8 4 4 4h24c2.2 0 4-1.8 4-4v-16c0-2.2-1.8-4-4-4zM12 4h8v4h-8v-4zM24 22h-6v6h-4v-6h-6v-4h6v-6h4v6h6v4z', //急救包
        'path://M32 18v-2h-6.040c-0.183-2.271-0.993-4.345-2.24-6.008h5.061l2.189-8.758-1.94-0.485-1.811 7.242h-5.459c-0.028-0.022-0.056-0.043-0.084-0.064 0.21-0.609 0.324-1.263 0.324-1.944 0-3.305-2.686-5.984-6-5.984s-6 2.679-6 5.984c0 0.68 0.114 1.334 0.324 1.944-0.028 0.021-0.056 0.043-0.084 0.064h-5.459l-1.811-7.242-1.94 0.485 2.189 8.758h5.061c-1.246 1.663-2.056 3.736-2.24 6.008h-6.040v2h6.043c0.119 1.427 0.485 2.775 1.051 3.992h-3.875l-2.189 8.757 1.94 0.485 1.811-7.243h3.511c1.834 2.439 4.606 3.992 7.708 3.992s5.874-1.554 7.708-3.992h3.511l1.811 7.243 1.94-0.485-2.189-8.757h-3.875c0.567-1.217 0.932-2.565 1.051-3.992h6.043z', //bug
        'path://M14 18v-14c-7.732 0-14 6.268-14 14s6.268 14 14 14 14-6.268 14-14c0-2.251-0.532-4.378-1.476-6.262l-12.524 6.262zM28.524 7.738c-2.299-4.588-7.043-7.738-12.524-7.738v14l12.524-6.262z', //饼图
        'path://M4 28h28v4h-32v-32h4zM9 26c-1.657 0-3-1.343-3-3s1.343-3 3-3c0.088 0 0.176 0.005 0.262 0.012l3.225-5.375c-0.307-0.471-0.487-1.033-0.487-1.638 0-1.657 1.343-3 3-3s3 1.343 3 3c0 0.604-0.179 1.167-0.487 1.638l3.225 5.375c0.086-0.007 0.174-0.012 0.262-0.012 0.067 0 0.133 0.003 0.198 0.007l5.324-9.316c-0.329-0.482-0.522-1.064-0.522-1.691 0-1.657 1.343-3 3-3s3 1.343 3 3c0 1.657-1.343 3-3 3-0.067 0-0.133-0.003-0.198-0.007l-5.324 9.316c0.329 0.481 0.522 1.064 0.522 1.691 0 1.657-1.343 3-3 3s-3-1.343-3-3c0-0.604 0.179-1.167 0.487-1.638l-3.225-5.375c-0.086 0.007-0.174 0.012-0.262 0.012s-0.176-0.005-0.262-0.012l-3.225 5.375c0.307 0.471 0.487 1.033 0.487 1.637 0 1.657-1.343 3-3 3z', //线图
        'path://M0 26h32v4h-32zM4 18h4v6h-4zM10 10h4v14h-4zM16 16h4v8h-4zM22 4h4v20h-4z', //柱图
        'path://M30.5 24h-0.5v-6.5c0-1.93-1.57-3.5-3.5-3.5h-8.5v-4h0.5c0.825 0 1.5-0.675 1.5-1.5v-5c0-0.825-0.675-1.5-1.5-1.5h-5c-0.825 0-1.5 0.675-1.5 1.5v5c0 0.825 0.675 1.5 1.5 1.5h0.5v4h-8.5c-1.93 0-3.5 1.57-3.5 3.5v6.5h-0.5c-0.825 0-1.5 0.675-1.5 1.5v5c0 0.825 0.675 1.5 1.5 1.5h5c0.825 0 1.5-0.675 1.5-1.5v-5c0-0.825-0.675-1.5-1.5-1.5h-0.5v-6h8v6h-0.5c-0.825 0-1.5 0.675-1.5 1.5v5c0 0.825 0.675 1.5 1.5 1.5h5c0.825 0 1.5-0.675 1.5-1.5v-5c0-0.825-0.675-1.5-1.5-1.5h-0.5v-6h8v6h-0.5c-0.825 0-1.5 0.675-1.5 1.5v5c0 0.825 0.675 1.5 1.5 1.5h5c0.825 0 1.5-0.675 1.5-1.5v-5c0-0.825-0.675-1.5-1.5-1.5zM6 30h-4v-4h4v4zM18 30h-4v-4h4v4zM14 8v-4h4v4h-4zM30 30h-4v-4h4v4z', //树图
        'path://M16 2c8.837 0 16 7.163 16 16 0 6.025-3.331 11.271-8.25 14h-15.499c-4.92-2.729-8.25-7.975-8.25-14 0-8.837 7.163-16 16-16zM25.060 27.060c2.42-2.42 3.753-5.637 3.753-9.060h-2.813v-2h2.657c-0.219-1.406-0.668-2.755-1.33-4h-3.327v-2h2.009c-0.295-0.368-0.611-0.722-0.949-1.060-1.444-1.444-3.173-2.501-5.060-3.119v2.178h-2v-2.658c-0.656-0.102-1.324-0.155-2-0.155s-1.344 0.053-2 0.155v2.658h-2v-2.178c-1.887 0.617-3.615 1.674-5.060 3.119-0.338 0.338-0.654 0.692-0.949 1.060h2.009v2h-3.327c-0.662 1.245-1.111 2.594-1.33 4h2.657v2h-2.813c0 3.422 1.333 6.64 3.753 9.060 0.335 0.335 0.685 0.648 1.049 0.94h6.011l1.143-16h1.714l1.143 16h6.011c0.364-0.292 0.714-0.606 1.049-0.94z', //仪表盘
        'path://M26 6v-4h-20v4h-6v4c0 3.314 2.686 6 6 6 0.627 0 1.232-0.096 1.801-0.275 1.443 2.063 3.644 3.556 6.199 4.075v6.2h-2c-2.209 0-4 1.791-4 4h16c0-2.209-1.791-4-4-4h-2v-6.2c2.555-0.519 4.756-2.012 6.199-4.075 0.568 0.179 1.173 0.275 1.801 0.275 3.314 0 6-2.686 6-6v-4h-6zM6 13.625c-1.999 0-3.625-1.626-3.625-3.625v-2h3.625v2c0 1.256 0.232 2.457 0.655 3.565-0.213 0.039-0.431 0.060-0.655 0.060zM29.625 10c0 1.999-1.626 3.625-3.625 3.625-0.224 0-0.442-0.021-0.655-0.060 0.423-1.107 0.655-2.309 0.655-3.565v-2h3.625v2z', //奖杯
        'path://M24.306 0.527c-0.174-0.324-0.513-0.527-0.881-0.527h-14.85c-0.368 0-0.707 0.202-0.881 0.527-1.108 2.063-1.694 4.474-1.694 6.973 0 3.294 1.012 6.401 2.849 8.748 1.42 1.814 3.203 3.017 5.151 3.505v10.247h-3c-0.552 0-1 0.448-1 1s0.448 1 1 1h10c0.552 0 1-0.448 1-1s-0.448-1-1-1h-3v-10.247c1.949-0.488 3.732-1.691 5.151-3.505 1.837-2.347 2.849-5.454 2.849-8.748 0-2.499-0.586-4.91-1.694-6.973zM9.191 2h13.619c0.78 1.653 1.191 3.542 1.191 5.5 0 0.168-0.003 0.334-0.009 0.5h-15.981c-0.006-0.166-0.009-0.332-0.009-0.5-0-1.958 0.41-3.847 1.191-5.5z', //玻璃杯
        'path://M31.604 4.203c-3.461-2.623-8.787-4.189-14.247-4.189-6.754 0-12.257 2.358-15.099 6.469-1.335 1.931-2.073 4.217-2.194 6.796-0.108 2.296 0.278 4.835 1.146 7.567 2.965-8.887 11.244-15.847 20.79-15.847 0 0-8.932 2.351-14.548 9.631-0.003 0.004-0.078 0.097-0.207 0.272-1.128 1.509-2.111 3.224-2.846 5.166-1.246 2.963-2.4 7.030-2.4 11.931h4c0 0-0.607-3.819 0.449-8.212 1.747 0.236 3.308 0.353 4.714 0.353 3.677 0 6.293-0.796 8.231-2.504 1.736-1.531 2.694-3.587 3.707-5.764 1.548-3.325 3.302-7.094 8.395-10.005 0.292-0.167 0.48-0.468 0.502-0.804s-0.126-0.659-0.394-0.862z', //树叶
        'path://M29.884 25.14l-9.884-16.47v-6.671h1c0.55 0 1-0.45 1-1s-0.45-1-1-1h-10c-0.55 0-1 0.45-1 1s0.45 1 1 1h1v6.671l-9.884 16.47c-2.264 3.773-0.516 6.86 3.884 6.86h20c4.4 0 6.148-3.087 3.884-6.86zM7.532 20l6.468-10.779v-7.221h4v7.221l6.468 10.779h-16.935z', //实验室
        'path://M4 10v20c0 1.1 0.9 2 2 2h18c1.1 0 2-0.9 2-2v-20h-22zM10 28h-2v-14h2v14zM14 28h-2v-14h2v14zM18 28h-2v-14h2v14zM22 28h-2v-14h2v14zM26.5 4h-6.5v-2.5c0-0.825-0.675-1.5-1.5-1.5h-7c-0.825 0-1.5 0.675-1.5 1.5v2.5h-6.5c-0.825 0-1.5 0.675-1.5 1.5v2.5h26v-2.5c0-0.825-0.675-1.5-1.5-1.5zM18 4h-6v-1.975h6v1.975z', //删除
        'path://M6 32h20l2-22h-24zM20 4v-4h-8v4h-10v6l2-2h24l2 2v-6h-10zM18 4h-4v-2h4v2z', //垃圾箱
        'path://M30 8h-8v-2c0-1.1-0.9-2-2-2h-8c-1.1 0-2 0.9-2 2v2h-8c-1.1 0-2 0.9-2 2v18c0 1.1 0.9 2 2 2h28c1.1 0 2-0.9 2-2v-18c0-1.1-0.9-2-2-2zM12 6.004c0.001-0.001 0.002-0.003 0.004-0.004h7.993c0.001 0.001 0.003 0.002 0.004 0.004v1.996h-8v-1.996zM30 16h-4v3c0 0.55-0.45 1-1 1h-2c-0.55 0-1-0.45-1-1v-3h-12v3c0 0.55-0.45 1-1 1h-2c-0.55 0-1-0.45-1-1v-3h-4v-2h28v2z', //公文包
        'path://M22 32h10l-8-32h-6l1 8h-6l1-8h-6l-8 32h10l1-8h10l1 8zM11.5 20l1-8h7l1 8h-9z', //路
        'path://M32 14h-3.154c-0.864-5.57-5.276-9.982-10.846-10.846v-3.154h-4v3.154c-5.57 0.864-9.982 5.276-10.846 10.846h-3.154v4h3.154c0.864 5.57 5.276 9.982 10.846 10.846v3.154h4v-3.154c5.57-0.864 9.982-5.276 10.846-10.846h3.154v-4zM24.776 14h-3.118c-0.603-1.705-1.953-3.056-3.658-3.658v-3.118c3.36 0.765 6.010 3.416 6.776 6.776zM16 18c-1.105 0-2-0.895-2-2s0.895-2 2-2c1.105 0 2 0.895 2 2s-0.895 2-2 2zM14 7.224v3.118c-1.705 0.603-3.056 1.953-3.658 3.658h-3.118c0.765-3.36 3.416-6.010 6.776-6.776zM7.224 18h3.118c0.603 1.705 1.953 3.056 3.658 3.658v3.118c-3.36-0.765-6.010-3.416-6.776-6.776zM18 24.776v-3.118c1.705-0.603 3.056-1.953 3.658-3.658h3.118c-0.765 3.36-3.416 6.010-6.776 6.776z', //靶子
        'path://M12 0l-12 16h12l-8 16 28-20h-16l12-12z', //闪电
        'path://M20 4.581v4.249c1.131 0.494 2.172 1.2 3.071 2.099 1.889 1.889 2.929 4.4 2.929 7.071s-1.040 5.182-2.929 7.071c-1.889 1.889-4.4 2.929-7.071 2.929s-5.182-1.040-7.071-2.929c-1.889-1.889-2.929-4.4-2.929-7.071s1.040-5.182 2.929-7.071c0.899-0.899 1.94-1.606 3.071-2.099v-4.249c-5.783 1.721-10 7.077-10 13.419 0 7.732 6.268 14 14 14s14-6.268 14-14c0-6.342-4.217-11.698-10-13.419zM14 0h4v16h-4z', //开关
        'path://M32 8.828l-2.828-2.828-5.586 5.586-3.172-3.172 5.586-5.586-2.828-2.828-5.586 5.586-3.586-3.586-2.707 2.707 16 16 2.707-2.707-3.586-3.586 5.586-5.586zM24.814 21.056l-13.87-13.87c-2.994 3.591-6.391 9.139-4.044 13.913l-4.133 4.133c-0.972 0.972-0.972 2.563 0 3.535l0.464 0.464c0.972 0.972 2.563 0.972 3.536 0l4.133-4.133c4.774 2.348 10.322-1.049 13.913-4.043z', //插头
        'path://M32 20.548c0-2.565-1.771-4.716-4.156-5.296-0.101-4.022-3.389-7.252-7.433-7.252-2.369 0-4.477 1.109-5.839 2.835-0.764-0.987-1.959-1.624-3.303-1.624-2.307 0-4.176 1.871-4.176 4.179 0 0.201 0.015 0.399 0.043 0.592-0.351-0.063-0.711-0.098-1.080-0.098-3.344-0-6.054 2.712-6.054 6.058s2.71 6.058 6.054 6.058l20.508-0c3.004-0.006 5.438-2.444 5.438-5.451z', //云
        'path://M16 0c-8.837 0-16 7.163-16 16s7.163 16 16 16 16-7.163 16-16-7.163-16-16-16zM16 30c-1.967 0-3.84-0.407-5.538-1.139l7.286-8.197c0.163-0.183 0.253-0.419 0.253-0.664v-3c0-0.552-0.448-1-1-1-3.531 0-7.256-3.671-7.293-3.707-0.188-0.188-0.442-0.293-0.707-0.293h-4c-0.552 0-1 0.448-1 1v6c0 0.379 0.214 0.725 0.553 0.894l3.447 1.724v5.871c-3.627-2.53-6-6.732-6-11.489 0-2.147 0.484-4.181 1.348-6h3.652c0.265 0 0.52-0.105 0.707-0.293l4-4c0.188-0.188 0.293-0.442 0.293-0.707v-2.419c1.268-0.377 2.61-0.581 4-0.581 2.2 0 4.281 0.508 6.134 1.412-0.13 0.109-0.256 0.224-0.376 0.345-1.133 1.133-1.757 2.64-1.757 4.243s0.624 3.109 1.757 4.243c1.139 1.139 2.663 1.758 4.239 1.758 0.099 0 0.198-0.002 0.297-0.007 0.432 1.619 1.211 5.833-0.263 11.635-0.014 0.055-0.022 0.109-0.026 0.163-2.541 2.596-6.084 4.208-10.004 4.208z', //地球
        'path://M20.807 10.22l-2.030-2.029-10.15 10.148c-1.682 1.681-1.682 4.408 0 6.089s4.408 1.681 6.090 0l12.18-12.178c2.804-2.802 2.804-7.346 0-10.148-2.802-2.803-7.347-2.803-10.149 0l-12.788 12.787c-0.009 0.009-0.019 0.018-0.027 0.026-3.909 3.909-3.909 10.245 0 14.153 3.908 3.908 10.246 3.908 14.156 0 0.009-0.009 0.016-0.018 0.026-0.027l0.001 0.001 8.729-8.728-2.031-2.029-8.729 8.727c-0.009 0.008-0.018 0.018-0.026 0.026-2.784 2.783-7.312 2.783-10.096 0-2.783-2.783-2.783-7.31 0-10.093 0.010-0.009 0.019-0.018 0.028-0.026l-0.001-0.002 12.79-12.786c1.678-1.679 4.411-1.679 6.090 0s1.678 4.411 0 6.089l-12.18 12.178c-0.56 0.56-1.47 0.56-2.030 0-0.559-0.559-0.559-1.47 0-2.029l10.15-10.149z', //附件
        'path://M16 6c-6.979 0-13.028 4.064-16 10 2.972 5.936 9.021 10 16 10s13.027-4.064 16-10c-2.972-5.936-9.021-10-16-10zM23.889 11.303c1.88 1.199 3.473 2.805 4.67 4.697-1.197 1.891-2.79 3.498-4.67 4.697-2.362 1.507-5.090 2.303-7.889 2.303s-5.527-0.796-7.889-2.303c-1.88-1.199-3.473-2.805-4.67-4.697 1.197-1.891 2.79-3.498 4.67-4.697 0.122-0.078 0.246-0.154 0.371-0.228-0.311 0.854-0.482 1.776-0.482 2.737 0 4.418 3.582 8 8 8s8-3.582 8-8c0-0.962-0.17-1.883-0.482-2.737 0.124 0.074 0.248 0.15 0.371 0.228v0zM16 13c0 1.657-1.343 3-3 3s-3-1.343-3-3 1.343-3 3-3 3 1.343 3 3z', //眼睛
        'path://M6 0v32l10-10 10 10v-32z', //书签
        'path://M23.6 2c4.637 0 8.4 3.764 8.4 8.401 0 9.132-9.87 11.964-15.999 21.232-6.485-9.326-16.001-11.799-16.001-21.232 0-4.637 3.763-8.401 8.4-8.401 1.886 0 3.625 0.86 5.025 2.12l-2.425 3.88 7 4-4 10 11-12-7-4 1.934-2.901c1.107-0.68 2.35-1.099 3.665-1.099z', //心碎
        'path://M16 32c8.837 0 16-7.163 16-16s-7.163-16-16-16-16 7.163-16 16 7.163 16 16 16zM16 3c7.18 0 13 5.82 13 13s-5.82 13-13 13-13-5.82-13-13 5.82-13 13-13zM16 18.711c3.623 0 7.070-0.963 10-2.654-0.455 5.576-4.785 9.942-10 9.942s-9.544-4.371-10-9.947c2.93 1.691 6.377 2.658 10 2.658zM8 11c0-1.657 0.895-3 2-3s2 1.343 2 3c0 1.657-0.895 3-2 3s-2-1.343-2-3zM20 11c0-1.657 0.895-3 2-3s2 1.343 2 3c0 1.657-0.895 3-2 3s-2-1.343-2-3z', //笑脸
        'path://M16 0c-8.837 0-16 7.163-16 16s7.163 16 16 16 16-7.163 16-16-7.163-16-16-16zM22 8c1.105 0 2 1.343 2 3s-0.895 3-2 3-2-1.343-2-3 0.895-3 2-3zM10 8c1.105 0 2 1.343 2 3s-0.895 3-2 3-2-1.343-2-3 0.895-3 2-3zM16 28c-5.215 0-9.544-4.371-10-9.947 2.93 1.691 6.377 2.658 10 2.658s7.070-0.963 10-2.654c-0.455 5.576-4.785 9.942-10 9.942z', //笑脸
        'path://M6 4l20 12-20 12z', //play
        'path://M4 4h10v24h-10zM18 4h10v24h-10z', //pause
        'path://M4 4h24v24h-24z', //stop
        'path://M18 5v10l10-10v22l-10-10v10l-11-11z', //backward
        'path://M16 27v-10l-10 10v-22l10 10v-10l11 11z', //forward
        'path://M4 28v-24h4v11l10-10v10l10-10v22l-10-10v10l-10-10v11z', //first
        'path://M28 4v24h-4v-11l-10 10v-10l-10 10v-22l10 10v-10l10 10v-11z', //last
        'path://M27.814 28.814c-0.384 0-0.768-0.146-1.061-0.439-0.586-0.586-0.586-1.535 0-2.121 2.739-2.739 4.247-6.38 4.247-10.253s-1.508-7.514-4.247-10.253c-0.586-0.586-0.586-1.536 0-2.121s1.536-0.586 2.121 0c3.305 3.305 5.126 7.7 5.126 12.374s-1.82 9.069-5.126 12.374c-0.293 0.293-0.677 0.439-1.061 0.439zM22.485 25.985c-0.384 0-0.768-0.146-1.061-0.439-0.586-0.586-0.586-1.535 0-2.121 4.094-4.094 4.094-10.755 0-14.849-0.586-0.586-0.586-1.536 0-2.121s1.536-0.586 2.121 0c2.55 2.55 3.954 5.94 3.954 9.546s-1.404 6.996-3.954 9.546c-0.293 0.293-0.677 0.439-1.061 0.439v0zM17.157 23.157c-0.384 0-0.768-0.146-1.061-0.439-0.586-0.586-0.586-1.535 0-2.121 2.534-2.534 2.534-6.658 0-9.192-0.586-0.586-0.586-1.536 0-2.121s1.535-0.586 2.121 0c3.704 3.704 3.704 9.731 0 13.435-0.293 0.293-0.677 0.439-1.061 0.439zM13 30c-0.26 0-0.516-0.102-0.707-0.293l-7.707-7.707h-3.586c-0.552 0-1-0.448-1-1v-10c0-0.552 0.448-1 1-1h3.586l7.707-7.707c0.286-0.286 0.716-0.372 1.090-0.217s0.617 0.519 0.617 0.924v26c0 0.404-0.244 0.769-0.617 0.924-0.124 0.051-0.254 0.076-0.383 0.076z', //volume-high
        'path://M22.485 25.985c-0.384 0-0.768-0.146-1.061-0.439-0.586-0.586-0.586-1.535 0-2.121 4.094-4.094 4.094-10.755 0-14.849-0.586-0.586-0.586-1.536 0-2.121s1.536-0.586 2.121 0c2.55 2.55 3.954 5.94 3.954 9.546s-1.404 6.996-3.954 9.546c-0.293 0.293-0.677 0.439-1.061 0.439v0zM17.157 23.157c-0.384 0-0.768-0.146-1.061-0.439-0.586-0.586-0.586-1.535 0-2.121 2.534-2.534 2.534-6.658 0-9.192-0.586-0.586-0.586-1.536 0-2.121s1.535-0.586 2.121 0c3.704 3.704 3.704 9.731 0 13.435-0.293 0.293-0.677 0.439-1.061 0.439zM13 30c-0.26 0-0.516-0.102-0.707-0.293l-7.707-7.707h-3.586c-0.552 0-1-0.448-1-1v-10c0-0.552 0.448-1 1-1h3.586l7.707-7.707c0.286-0.286 0.716-0.372 1.090-0.217s0.617 0.519 0.617 0.924v26c0 0.404-0.244 0.769-0.617 0.924-0.124 0.051-0.254 0.076-0.383 0.076z', //volume-medium
        'path://M17.157 23.157c-0.384 0-0.768-0.146-1.061-0.439-0.586-0.586-0.586-1.535 0-2.121 2.534-2.534 2.534-6.658 0-9.192-0.586-0.586-0.586-1.536 0-2.121s1.535-0.586 2.121 0c3.704 3.704 3.704 9.731 0 13.435-0.293 0.293-0.677 0.439-1.061 0.439zM13 30c-0.26 0-0.516-0.102-0.707-0.293l-7.707-7.707h-3.586c-0.552 0-1-0.448-1-1v-10c0-0.552 0.448-1 1-1h3.586l7.707-7.707c0.286-0.286 0.716-0.372 1.090-0.217s0.617 0.519 0.617 0.924v26c0 0.404-0.244 0.769-0.617 0.924-0.124 0.051-0.254 0.076-0.383 0.076z', //volume-low
        'path://M13 30c-0.26 0-0.516-0.102-0.707-0.293l-7.707-7.707h-3.586c-0.552 0-1-0.448-1-1v-10c0-0.552 0.448-1 1-1h3.586l7.707-7.707c0.286-0.286 0.716-0.372 1.090-0.217s0.617 0.519 0.617 0.924v26c0 0.404-0.244 0.769-0.617 0.924-0.124 0.051-0.254 0.076-0.383 0.076z', //volume-mute
        'path://M30 19.348v2.652h-2.652l-3.348-3.348-3.348 3.348h-2.652v-2.652l3.348-3.348-3.348-3.348v-2.652h2.652l3.348 3.348 3.348-3.348h2.652v2.652l-3.348 3.348 3.348 3.348zM13 30c-0.26 0-0.516-0.102-0.707-0.293l-7.707-7.707h-3.586c-0.552 0-1-0.448-1-1v-10c0-0.552 0.448-1 1-1h3.586l7.707-7.707c0.286-0.286 0.716-0.372 1.090-0.217s0.617 0.519 0.617 0.924v26c0 0.404-0.244 0.769-0.617 0.924-0.124 0.051-0.254 0.076-0.383 0.076z', //volume-mute
        'path://M27.802 5.197c-2.925-3.194-7.13-5.197-11.803-5.197-8.837 0-16 7.163-16 16h3c0-7.18 5.82-13 13-13 3.844 0 7.298 1.669 9.678 4.322l-4.678 4.678h11v-11l-4.198 4.197zM29 16c0 7.18-5.82 13-13 13-3.844 0-7.298-1.669-9.678-4.322l4.678-4.678h-11v11l4.197-4.197c2.925 3.194 7.13 5.197 11.803 5.197 8.837 0 16-7.163 16-16h-3z', //loop
        'path://M9 0l8 8-17 17 7 7 17-17 8 8v-23h-23z', //arrow-up-right
        'path://M31 16l-15-15v9h-16v12h16v9z', //arrow-right
        'path://M32 9l-8 8-17-17-7 7 17 17-8 8h23v-23z', //arrow-down-right
        'path://M16 31l15-15h-9v-16h-12v16h-9z', //arrow-down
        'path://M23 32l-8-8 17-17-7-7-17 17-8-8v23h23z', //arrow-down-left
        'path://M1 16l15 15v-9h16v-12h-16v-9z', //arrow-left
        'path://M28.557 21.24c-2.084-3.256-5.659-4.689-7.985-3.201-0.201 0.129-0.385 0.275-0.555 0.437l-2.483-3.883 5.733-8.999c0.469-0.867 0.642-1.899 0.415-2.937-0.218-0.992-0.766-1.826-1.503-2.413l-0.384-0.244-6.796 10.629-6.796-10.629-0.384 0.244c-0.737 0.587-1.285 1.421-1.503 2.413-0.228 1.038-0.055 2.070 0.415 2.937l5.733 8.999-2.483 3.883c-0.169-0.162-0.354-0.308-0.554-0.437-2.326-1.488-5.901-0.055-7.985 3.201s-1.887 7.103 0.438 8.591c2.326 1.488 5.901 0.055 7.985-3.201l5.134-8.058 5.134 8.058c2.084 3.256 5.659 4.689 7.985 3.201s2.522-5.335 0.438-8.591zM7.339 25.013c-0.938 1.466-2.142 2.179-2.955 2.358-0 0-0 0-0 0-0.265 0.058-0.634 0.094-0.885-0.067-0.278-0.178-0.463-0.648-0.494-1.259-0.050-0.989 0.301-2.151 0.965-3.189 0.938-1.466 2.142-2.179 2.955-2.358 0.266-0.058 0.635-0.094 0.886 0.066 0.278 0.178 0.463 0.648 0.494 1.259 0.051 0.989-0.301 2.151-0.965 3.189zM15 16c-0.552 0-1-0.448-1-1s0.448-1 1-1 1 0.448 1 1-0.448 1-1 1zM26.995 26.046c-0.031 0.61-0.216 1.081-0.494 1.259-0.251 0.161-0.62 0.125-0.885 0.067 0 0 0 0-0 0-0.814-0.179-2.017-0.892-2.955-2.358-0.664-1.037-1.016-2.2-0.965-3.189 0.031-0.61 0.216-1.081 0.494-1.259 0.251-0.16 0.62-0.125 0.886-0.066 0.814 0.179 2.017 0.892 2.955 2.358 0.664 1.037 1.016 2.2 0.965 3.189z', //剪刀
        'path://M29 0h-26c-1.65 0-3 1.35-3 3v26c0 1.65 1.35 3 3 3h26c1.65 0 3-1.35 3-3v-26c0-1.65-1.35-3-3-3zM16.238 28c-6.631 0-12-5.369-12-12s5.369-12 12-12c3.238 0 5.95 1.181 8.037 3.138l-3.256 3.138c-0.894-0.856-2.45-1.85-4.781-1.85-4.1 0-7.438 3.394-7.438 7.575s3.344 7.575 7.438 7.575c4.75 0 6.531-3.413 6.806-5.175h-6.806v-4.113h11.331c0.1 0.6 0.188 1.2 0.188 1.988 0.006 6.856-4.588 11.725-11.519 11.725z', //谷歌
        'path://M29 0h-26c-1.65 0-3 1.35-3 3v26c0 1.65 1.35 3 3 3h13v-14h-4v-4h4v-2c0-3.306 2.694-6 6-6h4v4h-4c-1.1 0-2 0.9-2 2v2h6l-1 4h-5v14h9c1.65 0 3-1.35 3-3v-26c0-1.65-1.35-3-3-3z', //facebook
        'path://M32 7.075c-1.175 0.525-2.444 0.875-3.769 1.031 1.356-0.813 2.394-2.1 2.887-3.631-1.269 0.75-2.675 1.3-4.169 1.594-1.2-1.275-2.906-2.069-4.794-2.069-3.625 0-6.563 2.938-6.563 6.563 0 0.512 0.056 1.012 0.169 1.494-5.456-0.275-10.294-2.888-13.531-6.862-0.563 0.969-0.887 2.1-0.887 3.3 0 2.275 1.156 4.287 2.919 5.463-1.075-0.031-2.087-0.331-2.975-0.819 0 0.025 0 0.056 0 0.081 0 3.181 2.263 5.838 5.269 6.437-0.55 0.15-1.131 0.231-1.731 0.231-0.425 0-0.831-0.044-1.237-0.119 0.838 2.606 3.263 4.506 6.131 4.563-2.25 1.762-5.075 2.813-8.156 2.813-0.531 0-1.050-0.031-1.569-0.094 2.913 1.869 6.362 2.95 10.069 2.95 12.075 0 18.681-10.006 18.681-18.681 0-0.287-0.006-0.569-0.019-0.85 1.281-0.919 2.394-2.075 3.275-3.394z', //twitter
        'path://M13.287 0.331c-7.537 1.269-13.287 7.825-13.287 15.725 0 3.925 1.425 7.519 3.775 10.3 5.581-2.7 9.488-8.813 9.512-15.931v-10.094zM18.712 0.331c7.538 1.269 13.288 7.825 13.288 15.725 0 3.925-1.425 7.519-3.775 10.3-5.581-2.7-9.488-8.813-9.512-15.931v-10.094zM15.944 20.081c-0.994 4.113-3.963 7.625-7.656 9.963 2.275 1.244 4.881 1.956 7.656 1.956s5.381-0.712 7.656-1.956c-3.694-2.337-6.663-5.85-7.656-9.963z', //人人
        'path://M13.444 28.063c-5.3 0.525-9.875-1.875-10.219-5.35-0.344-3.481 3.675-6.719 8.969-7.244 5.3-0.525 9.875 1.875 10.213 5.35 0.35 3.481-3.669 6.725-8.963 7.244zM24.038 16.519c-0.45-0.137-0.762-0.225-0.525-0.819 0.512-1.287 0.563-2.394 0.006-3.188-1.038-1.481-3.881-1.406-7.137-0.037 0 0-1.025 0.444-0.762-0.363 0.5-1.613 0.425-2.956-0.356-3.738-1.769-1.769-6.469 0.069-10.5 4.1-3.013 3.006-4.763 6.213-4.763 8.981 0 5.288 6.787 8.506 13.425 8.506 8.7 0 14.494-5.056 14.494-9.069 0-2.431-2.044-3.806-3.881-4.375zM29.819 6.831c-2.1-2.331-5.2-3.219-8.063-2.612v0c-0.663 0.144-1.081 0.794-0.938 1.45 0.144 0.662 0.788 1.081 1.45 0.938 2.038-0.431 4.238 0.2 5.731 1.856s1.9 3.912 1.256 5.888v0c-0.206 0.644 0.144 1.331 0.788 1.544 0.644 0.206 1.331-0.144 1.544-0.787v-0.006c0.9-2.762 0.331-5.938-1.769-8.269zM26.587 9.75c-1.025-1.137-2.538-1.569-3.925-1.269-0.569 0.119-0.931 0.688-0.813 1.256 0.125 0.569 0.688 0.931 1.25 0.806v0c0.681-0.144 1.419 0.069 1.919 0.619 0.5 0.556 0.637 1.313 0.419 1.975v0c-0.175 0.55 0.125 1.15 0.681 1.331 0.556 0.175 1.15-0.125 1.331-0.681 0.438-1.356 0.163-2.906-0.863-4.037zM13.738 21.769c-0.188 0.319-0.594 0.469-0.912 0.337-0.319-0.125-0.412-0.488-0.231-0.794 0.188-0.306 0.581-0.456 0.894-0.337 0.313 0.113 0.425 0.469 0.25 0.794zM12.044 23.931c-0.512 0.819-1.613 1.175-2.438 0.8-0.813-0.369-1.056-1.319-0.544-2.119 0.506-0.794 1.569-1.15 2.387-0.806 0.831 0.356 1.1 1.3 0.594 2.125zM13.969 18.144c-2.519-0.656-5.369 0.6-6.463 2.819-1.119 2.262-0.037 4.781 2.506 5.606 2.637 0.85 5.75-0.456 6.831-2.894 1.069-2.394-0.262-4.85-2.875-5.531z', //微博
        'path://M24.734 17.003c-0.040-4.053 3.305-5.996 3.454-6.093-1.88-2.751-4.808-3.127-5.851-3.171-2.492-0.252-4.862 1.467-6.127 1.467-1.261 0-3.213-1.43-5.28-1.392-2.716 0.040-5.221 1.579-6.619 4.012-2.822 4.897-0.723 12.151 2.028 16.123 1.344 1.944 2.947 4.127 5.051 4.049 2.026-0.081 2.793-1.311 5.242-1.311s3.138 1.311 5.283 1.271c2.18-0.041 3.562-1.981 4.897-3.931 1.543-2.255 2.179-4.439 2.216-4.551-0.048-0.022-4.252-1.632-4.294-6.473zM20.705 5.11c1.117-1.355 1.871-3.235 1.665-5.11-1.609 0.066-3.559 1.072-4.713 2.423-1.036 1.199-1.942 3.113-1.699 4.951 1.796 0.14 3.629-0.913 4.747-2.264z', //apple
        'path://M12.882 15.997c-1.491-0.766-2.94-1.155-4.309-1.155-0.186 0-0.373 0.006-0.561 0.022-1.746 0.145-3.341 0.605-4.367 0.963-0.272 0.1-0.551 0.205-0.838 0.322l-2.807 9.731c1.928-0.713 3.634-1.061 5.196-1.061 2.526 0 4.36 0.944 5.875 1.916 0.718-2.435 2.439-8.315 2.953-10.073-0.373-0.228-0.752-0.455-1.141-0.666zM16.511 18.471l-2.826 9.817c0.838 0.48 3.659 2.002 5.819 2.002 1.744 0 3.695-0.447 5.964-1.369l2.699-9.437c-1.832 0.591-3.59 0.891-5.233 0.891-2.998 0-5.097-0.972-6.422-1.905zM9.151 11.525c2.41 0.025 4.192 0.944 5.669 1.891l2.899-9.917c-0.611-0.35-2.213-1.222-3.371-1.519-0.762-0.178-1.563-0.269-2.413-0.269-1.619 0.030-3.387 0.436-5.403 1.244l-2.764 9.706c2.025-0.764 3.77-1.136 5.378-1.136 0.001 0 0.004 0 0.004 0zM32 6.191c-1.838 0.713-3.631 1.077-5.345 1.077-2.865 0-4.978-0.994-6.347-1.949l-2.873 9.945c1.93 1.241 4.009 1.871 6.191 1.871 1.78 0 3.623-0.427 5.483-1.271l-0.006-0.069 0.117-0.028 2.779-9.576z', //windows
        'path://M0.011 16l-0.011-9.752 12-1.63v11.382zM14 4.328l15.996-2.328v14h-15.996zM30 18l-0.004 14-15.996-2.25v-11.75zM12 29.495l-11.99-1.644-0.001-9.851h11.991z', //windows8
        'path://M22.944 19.651h7.377c0.057-0.512 0.080-1.034 0.080-1.569 0-2.507-0.673-4.858-1.848-6.883 1.215-3.228 1.172-5.968-0.455-7.606-1.547-1.54-5.697-1.29-10.388 0.787-0.347-0.026-0.697-0.040-1.051-0.040-6.439 0-11.841 4.431-13.335 10.402 2.020-2.586 4.145-4.461 6.984-5.826-0.258 0.242-1.764 1.739-2.018 1.993-7.486 7.484-9.847 17.26-7.306 19.8 1.931 1.93 5.43 1.604 9.449-0.364 1.869 0.952 3.984 1.488 6.226 1.488 6.035 0 11.15-3.885 13.003-9.295h-7.433c-1.023 1.887-3.023 3.171-5.319 3.171s-4.296-1.284-5.319-3.171c-0.455-0.852-0.716-1.83-0.716-2.864v-0.023h12.071zM10.884 16.025c0.171-3.035 2.694-5.456 5.774-5.456s5.604 2.421 5.774 5.456h-11.548zM28.030 5.119c1.048 1.059 1.021 3.007 0.125 5.438-1.535-2.341-3.766-4.186-6.4-5.239 2.816-1.207 5.106-1.367 6.274-0.199zM2.921 30.227c-1.337-1.337-0.934-4.144 0.788-7.526 1.072 3.008 3.161 5.534 5.854 7.161-2.982 1.354-5.423 1.584-6.643 0.365z', //IE
        'path://M-189.787,67.678c1.072,0.77-0.162,2.091-1.133,2.356c-0.809,0.184-0.858,0.419-0.912-1.61c-0.756-5.107-3.699-14.439-5.325-17.021c-0.503-0.736-0.738-1.273-0.738-1.273s-0.669,1.977-0.669,2.346c0,0.368-0.636,1.574-0.771,2.043s-3.279,9.141-3.948,10.146c-0.806,3.151,0.393,2.136-0.31,2.998c-0.091,0.776-1.762,1.158-2.553,0.815c-0.037-0.076,0.626-3.135,0.712-3.393c0.737-2.211,3.452-8.893,3.687-9.461c0.234-0.569,0.838-3.148,0.636-4.321c-0.201-1.173-0.603-2.814-1.842-3.552c-1.24-0.736-2.479-2.546-2.914-3.115c-0.436-0.568-0.738-2.713-2.412-2.311c-0.901,1.084-7.669,4.75-13.299,3.383c-2.345-0.569-4.188-1.072-4.858-1.072c-0.669,0-1.742-0.838-1.91,0.904c-0.166,1.742-0.736,4.154-0.803,5.159c0.711,2.651-0.865,14.542,1.148,18.295c0.959,1.786,0.509,1.983,0.383,1.995c-0.761,0.211-2.06,0.611-2.72,0.007c-0.208-0.19,0.162-1.132,0.212-1.565c0.685-2.406-1.993-16.574-2.105-19.166c-1.102,19.925,0.827,14.424,0.974,18.172c-0.586,0.369-1.503,0.747-2.542,0.512c-0.22-0.01-0.371-0.197-0.331-0.992c0.067-1.323,0.334-1.763,0.246-3.627c-0.235-5.023-1.443-12.921-1.33-13.932c0-1.439-0.235-3.584-0.435-4.422c-0.202-0.837-0.502-2.646-1.474-3.081c-5.729-1.687-10.635-21.806-11.088-26.466c-0.369-1.541-0.074-4.396-0.042-4.866c-0.368-0.436-1.466-0.241-2.404-1.097c-1.14-1.139-1.692-2.621-1.858-3.458c-0.083-0.493-0.36-0.126-1.458-1.099c-1.742-1.305-3.986-3.482-4.287-5.191c-0.206-0.83-0.462-3.273-0.33-3.174c0.099,0.031,0.782,3.25,1.15,3.299c0.786-0.419-0.018-2.387-0.018-3.826c0-1.44,0.018-2.479-0.971-3.803c-0.302-1.039,0.033-2.714,0.469-3.216c-0.268,1.388-0.26,2.369,0.36,3.333c0.712,0.947,1.247,1.089,2.353,0.184c1.221-0.836,2.266-1.81,2.411-2.102c0.034-0.07,0.023,0.258-0.379,0.906c-1.441,1.768-2.781,1.878-2.328,2.516c0.276,0.359,0.814,0.061,1.068-0.182c0.284-0.293,0.389,0.277-0.637,0.805c-1.048,0.447-1.507,0.335-1.44,2.279c0.036,1.062,0.039,2.916,0.727,4.478c0.567,1.294,1.671,2.353,3.087,2.877c0.927-0.044,1.388,0.569,2.106,0.974c0.475,0.268,1.169,0.301,1.65,0.448c1.207,0.368,1.575,0.904,1.575,0.904s0.569,0.503,0.067-0.437c-0.503-0.938-1.428-2.25-1.406-3.617c-0.035-1.406-0.134-2.277,0.401-0.302c0.662,3.159,2.396,3.702,2.278,5.243c0.479,0.4,0.888,0.041,1.399,0.092c0.678,0.041,1.014,0.469,1.716,0.168c0.461-0.303,0.896-0.41,1.475-0.311c0.746-0.436,0.469-1.816,1.239-2.479c1.071-1.406,1.624-3.551,1.574-4.221c0.065-1.512,0.21-1.324,0.436-0.368c0.427,2.103-0.771,4.204-1.172,4.79c-0.561,0.854-1.039,1.516-0.502,1.44c0.536-0.167,1.892-0.72,2.194-1.089c0.762-0.662,1.039-1.193,1.29-1.592c0.352-0.477,0.786-0.57,0.871,0.168c0.024,0.67-0.218,0.837-0.034,1.273c3.625-1.412,6.235-3.173,7.512-8.818c0.09-1.268-0.25-2.324-0.754-3.422c-0.645-1.412-1.642-3.612-2.467-4.98c-0.032-0.107,0.551,0.364,1.034,1.207c0.403,1.039,1.823,3.604,2.145,4.02c0.468,0.438,0.905,1.039,1.14,0.168c0.185-1.055,0.871-1.727,0.736-3.484c-0.016-1.59,0.093-1.557,0.427,0.62c-0.101,1.474-0.527,2.898-0.561,3.602c-0.201,0.637-0.537,3.351-1.072,4.255c-2.306,5.33-3.644,5.936-8.436,8.561c0.058,0.1,0.119,1.941-2.25,3.197c-0.77,0.426-0.872,1.14-0.872,2.58c-0.117,2.209,0.85,2.994,1.051,3.563c0.201,0.569,0.373,3.337,1.999,4.142c1.18,0.428,2.477,0.804,4.421,1.004c3.083-0.008,5.577,0.889,8.091,1.189c2.512,0.301,5.878-0.754,8.324-0.754c2.445,0,6.919-0.217,9.967-0.117c3.048,0.101,5.605,0.592,8.458,2.094c2.353,1.469,2.569,6.314,1.454,6.99c0.091-1.138-0.522-0.649-0.49-2.748c0.028,0.553-0.083,2.197-0.812,3.917l-1.408,4.22c0,0-1.724,4.036-0.051,6.381c1.676,2.346,2.715,3.25,3.049,3.585c0.336,0.335,0.67,1.173,0.771,3.249c0.1,2.078,0.703,4.455,0.938,5.562C-193.166,56.301-190.61,66.523-189.787,67.678z', //梅花鹿
        'path://M2.3,2.2h22.8V25H2.3V2.2z M35,2.2h22.8V25H35V2.2zM2.3,35h22.8v22.8H2.3V35z M35,35h22.8v22.8H35V35z', //
        'path://M15.2,30 M19.7,15.6V1.9H29 M34.8,1.9H40.4 M55.3,15.6V1.9H45.9 M19.7,44.4V58.1H29 M34.8,58.1H40.4 M55.3,44.4 V58.1H45.9 M12.5,20.3l-9.4,9.6l9.6,9.8 M3.1,29.9h16.5 M62.5,20.3l9.4,9.6L62.3,39.7 M71.9,29.9H55.4z', //
        'path://M7.3,34.7 M0.4,10V-0.2h9.8 M89.6,10V-0.2h-9.8 M0.4,60v10.2h9.8 M89.6,60v10.2h-9.8 M12.3,22.4V10.5h13.1 M33.6,10.5h7.8 M49.1,10.5h7.8 M77.5,22.4V10.5h-13 M12.3,31.1v8.2 M77.7,31.1v8.2 M12.3,47.6v11.9h13.1 M33.6,59.5h7.6 M49.1,59.5 h7.7 M77.5,47.6v11.9h-13z', //
        'path://M22,14.7l30.9,31 M52.9,14.7L22,45.7 M4.7,16.8V4.2h13.1 M26,4.2h7.8 M41.6,4.2h7.8 M70.3,16.8V4.2H57.2 M4.7,25.9v8.6 M70.3,25.9v8.6 M4.7,43.2v12.6h13.1 M26,55.8h7.8 M41.6,55.8h7.8 M70.3,43.2v12.6H57.2z',
        'path://M4,10.5V1h10.3 M20.7,1h6.1 M33,1h6.1 M55.4,10.5V1H45.2 M4,17.3v6.6 M55.6,17.3v6.6 M4,30.5V40h10.3 M20.7,40 h6.1 M33,40h6.1 M55.4,30.5V40H45.2 M21,18.9h62.9v48.6H21V18.9z', //lineX
        'path://M38.8,7.7 M52.7,12h13.2v9 M65.9,26.6V32 M52.7,46.3h13.2v-9 M24.9,12H11.8v9 M11.8,26.6V32 M24.9,46.3H11.8v-9 M48.2,5.1l-9.3-9l-9.4,9.2 M38.9-3.9V12 M48.2,53.3l-9.3,9l-9.4-9.2 M38.9,62.3V46.4z', //
        'path://M55.2,34.9c1.7,0,3.1,1.4,3.1,3.1s-1.4,3.1-3.1,3.1 s-3.1-1.4-3.1-3.1S53.5,34.9,55.2,34.9z M50.4,51c1.7,0,3.1,1.4,3.1,3.1c0,1.7-1.4,3.1-3.1,3.1c-1.7,0-3.1-1.4-3.1-3.1 C47.3,52.4,48.7,51,50.4,51z M55.6,37.1l1.5-7.8 M60.1,13.5l1.6-8.7l-7.8,4 M59,19l-1,5.3 M24,16.1l6.4,4.9l6.4-3.3 M48.5,11.6 l-5.9,3.1 M19.1,12.8L9.7,5.1l1.1,7.7 M13.4,29.8l1,7.3l6.6,1.6 M11.6,18.4l1,6.1 M32.8,41.9 M26.6,40.4 M27.3,40.2l6.1,1.6 M49.9,52.1l-5.6-7.6l-4.9-1.2z', //
        'path://M4.7,22.9L29.3,45.5L54.7,23.4M4.6,43.6L4.6,58L53.8,58L53.8,43.6M29.2,45.1L29.2,0z', //
        'path://M4.1,28.9h7.1l9.3-22l7.4,38l9.7-19.7l3,12.8h14.9M4.1,58h51.4z', //line
        'path://M6.7,22.9h10V48h-10V22.9zM24.9,13h10v35h-10V13zM43.2,2h10v46h-10V2zM3.1,58h53.7z', //bar
        'path://M8.2,38.4l-8.4,4.1l30.6,15.3L60,42.5l-8.1-4.1l-21.5,11L8.2,38.4z M51.9,30l-8.1,4.2l-13.4,6.9l-13.9-6.9L8.2,30l-8.4,4.2l8.4,4.2l22.2,11l21.5-11l8.1-4.2L51.9,30z M51.9,21.7l-8.1,4.2L35.7,30l-5.3,2.8L24.9,30l-8.4-4.1l-8.3-4.2l-8.4,4.2L8.2,30l8.3,4.2l13.9,6.9l13.4-6.9l8.1-4.2l8.1-4.1L51.9,21.7zM30.4,2.2L-0.2,17.5l8.4,4.1l8.3,4.2l8.4,4.2l5.5,2.7l5.3-2.7l8.1-4.2l8.1-4.2l8.1-4.1L30.4,2.2z', //stack
        'path://M17.5,17.3H33 M17.5,17.3H33 M45.4,29.5h-28 M11.5,2v56H51V14.8L38.4,2H11.5z M38.4,2.2v12.7H51 M45.4,41.7h-28z',
        'path://M0,13.5h26.9 M13.5,26.9V0 M32.1,13.5H58V58H13.5 V32.1z', //zoom
        'path://M22,1.4L9.9,13.5l12.3,12.3 M10.3,13.5H54.9v44.6 H10.3v-26z', //back
        'path://M3.8,33.4 M47,18.9h9.8V8.7 M56.3,20.1 C52.1,9,40.5,0.6,26.8,2.1C12.6,3.7,1.6,16.2,2.1,30.6 M13,41.1H3.1v10.2 M3.7,39.9c4.2,11.1,15.8,19.5,29.5,18 c14.2-1.6,25.2-14.1,24.7-28.5z', //Restore
        'path://M10.7,11.9v-1.3H9.3v1.3c-4.9,0.3-8.8,4.4-8.8,9.4c0,5,3.9,9.1,8.8,9.4h1.3c4.9-0.3,8.8-4.4,8.8-9.4C19.5,16.3,15.6,12.2,10.7,11.9z M13.3,24.4H6.7v-1.2h6.6z M13.3,22H6.7v-1.2h6.6z M13.3,19.6H6.7v-1.2h6.6z', //
        'path://M10.7,11.9v-1.3H9.3v1.3c-4.9,0.3-8.8,4.4-8.8,9.4c0,5,3.9,9.1,8.8,9.4v1.3h1.3v-1.3c4.9-0.3,8.8-4.4,8.8-9.4C19.5,16.3,15.6,12.2,10.7,11.9z M13.3,24.4H6.7V23h6.6V24.4z M13.3,19.6H6.7v-1.4h6.6V19.6z'
      ]*/
    }
  }
}
</script>

<style scoped>

</style>
